# Copyright 2022 NXP
# SPDX-License-Identifier: MIT
# The auto-generated can only be used on NXP devices

import SDL
import utime as time
import usys as sys
import lvgl as lv
import lodepng as png
import ustruct

lv.init()
SDL.init(w=320,h=240)

# Register SDL display driver.
disp_buf1 = lv.disp_draw_buf_t()
buf1_1 = bytearray(320*10)
disp_buf1.init(buf1_1, None, len(buf1_1)//4)
disp_drv = lv.disp_drv_t()
disp_drv.init()
disp_drv.draw_buf = disp_buf1
disp_drv.flush_cb = SDL.monitor_flush
disp_drv.hor_res = 320
disp_drv.ver_res = 240
disp_drv.register()

# Regsiter SDL mouse driver
indev_drv = lv.indev_drv_t()
indev_drv.init() 
indev_drv.type = lv.INDEV_TYPE.POINTER
indev_drv.read_cb = SDL.mouse_read
indev_drv.register()

# Below: Taken from https://github.com/lvgl/lv_binding_micropython/blob/master/driver/js/imagetools.py#L22-L94

COLOR_SIZE = lv.color_t.__SIZE__
COLOR_IS_SWAPPED = hasattr(lv.color_t().ch,'green_h')

class lodepng_error(RuntimeError):
    def __init__(self, err):
        if type(err) is int:
            super().__init__(png.error_text(err))
        else:
            super().__init__(err)

# Parse PNG file header
# Taken from https://github.com/shibukawa/imagesize_py/blob/ffef30c1a4715c5acf90e8945ceb77f4a2ed2d45/imagesize.py#L63-L85

def get_png_info(decoder, src, header):
    # Only handle variable image types

    if lv.img.src_get_type(src) != lv.img.SRC.VARIABLE:
        return lv.RES.INV

    data = lv.img_dsc_t.__cast__(src).data
    if data == None:
        return lv.RES.INV

    png_header = bytes(data.__dereference__(24))

    if png_header.startswith(b'\211PNG\r\n\032\n'):
        if png_header[12:16] == b'IHDR':
            start = 16
        # Maybe this is for an older PNG version.
        else:
            start = 8
        try:
            width, height = ustruct.unpack(">LL", png_header[start:start+8])
        except ustruct.error:
            return lv.RES.INV
    else:
        return lv.RES.INV

    header.always_zero = 0
    header.w = width
    header.h = height
    header.cf = lv.img.CF.TRUE_COLOR_ALPHA

    return lv.RES.OK

def convert_rgba8888_to_bgra8888(img_view):
    for i in range(0, len(img_view), lv.color_t.__SIZE__):
        ch = lv.color_t.__cast__(img_view[i:i]).ch
        ch.red, ch.blue = ch.blue, ch.red

# Read and parse PNG file

def open_png(decoder, dsc):
    img_dsc = lv.img_dsc_t.__cast__(dsc.src)
    png_data = img_dsc.data
    png_size = img_dsc.data_size
    png_decoded = png.C_Pointer()
    png_width = png.C_Pointer()
    png_height = png.C_Pointer()
    error = png.decode32(png_decoded, png_width, png_height, png_data, png_size)
    if error:
        raise lodepng_error(error)
    img_size = png_width.int_val * png_height.int_val * 4
    img_data = png_decoded.ptr_val
    img_view = img_data.__dereference__(img_size)

    if COLOR_SIZE == 4:
        convert_rgba8888_to_bgra8888(img_view)
    else:
        raise lodepng_error("Error: Color mode not supported yet!")

    dsc.img_data = img_data
    return lv.RES.OK

# Above: Taken from https://github.com/lvgl/lv_binding_micropython/blob/master/driver/js/imagetools.py#L22-L94

decoder = lv.img.decoder_create()
decoder.info_cb = get_png_info
decoder.open_cb = open_png

def anim_x_cb(obj, v):
    obj.set_x(v)

def anim_y_cb(obj, v):
    obj.set_y(v)

def ta_event_cb(e,kb):
    code = e.get_code()
    ta = e.get_target()
    if code == lv.EVENT.FOCUSED:
        kb.set_textarea(ta)
        kb.clear_flag(lv.obj.FLAG.HIDDEN)

    if code == lv.EVENT.DEFOCUSED:
        kb.set_textarea(None)
        kb.add_flag(lv.obj.FLAG.HIDDEN)


screen1 = lv.obj()
# create style style_screen1_main_main_default
style_screen1_main_main_default = lv.style_t()
style_screen1_main_main_default.init()
style_screen1_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen1_main_main_default.set_bg_opa(0)

# add style for screen1
screen1.add_style(style_screen1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_1 = lv.label(screen1)
screen1_label_1.set_pos(22,77)
screen1_label_1.set_size(120,31)
screen1_label_1.set_text("姓名")
screen1_label_1.set_long_mode(lv.label.LONG.WRAP)
screen1_label_1.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_1_main_main_default
style_screen1_label_1_main_main_default = lv.style_t()
style_screen1_label_1_main_main_default.init()
style_screen1_label_1_main_main_default.set_radius(10)
style_screen1_label_1_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen1_label_1_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_1_main_main_default.set_bg_opa(255)
style_screen1_label_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_1_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_label_1_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_1_main_main_default.set_text_letter_space(2)
style_screen1_label_1_main_main_default.set_pad_left(0)
style_screen1_label_1_main_main_default.set_pad_right(0)
style_screen1_label_1_main_main_default.set_pad_top(0)
style_screen1_label_1_main_main_default.set_pad_bottom(0)

# add style for screen1_label_1
screen1_label_1.add_style(style_screen1_label_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_2 = lv.label(screen1)
screen1_label_2.set_pos(175,79)
screen1_label_2.set_size(120,32)
screen1_label_2.set_text("性别")
screen1_label_2.set_long_mode(lv.label.LONG.WRAP)
screen1_label_2.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_2_main_main_default
style_screen1_label_2_main_main_default = lv.style_t()
style_screen1_label_2_main_main_default.init()
style_screen1_label_2_main_main_default.set_radius(10)
style_screen1_label_2_main_main_default.set_bg_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_2_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_2_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_2_main_main_default.set_bg_opa(242)
style_screen1_label_2_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_2_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_label_2_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_2_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_2_main_main_default.set_text_letter_space(2)
style_screen1_label_2_main_main_default.set_pad_left(0)
style_screen1_label_2_main_main_default.set_pad_right(0)
style_screen1_label_2_main_main_default.set_pad_top(0)
style_screen1_label_2_main_main_default.set_pad_bottom(0)

# add style for screen1_label_2
screen1_label_2.add_style(style_screen1_label_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_3 = lv.label(screen1)
screen1_label_3.set_pos(23,125)
screen1_label_3.set_size(120,32)
screen1_label_3.set_text("指纹")
screen1_label_3.set_long_mode(lv.label.LONG.WRAP)
screen1_label_3.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_3_main_main_default
style_screen1_label_3_main_main_default = lv.style_t()
style_screen1_label_3_main_main_default.init()
style_screen1_label_3_main_main_default.set_radius(10)
style_screen1_label_3_main_main_default.set_bg_color(lv.color_make(0xf0,0xf1,0xff))
style_screen1_label_3_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_3_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_3_main_main_default.set_bg_opa(255)
style_screen1_label_3_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_3_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_label_3_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_3_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_3_main_main_default.set_text_letter_space(2)
style_screen1_label_3_main_main_default.set_pad_left(0)
style_screen1_label_3_main_main_default.set_pad_right(0)
style_screen1_label_3_main_main_default.set_pad_top(0)
style_screen1_label_3_main_main_default.set_pad_bottom(0)

# add style for screen1_label_3
screen1_label_3.add_style(style_screen1_label_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_4 = lv.label(screen1)
screen1_label_4.set_pos(175,129)
screen1_label_4.set_size(120,32)
screen1_label_4.set_text("NFC")
screen1_label_4.set_long_mode(lv.label.LONG.WRAP)
screen1_label_4.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_4_main_main_default
style_screen1_label_4_main_main_default = lv.style_t()
style_screen1_label_4_main_main_default.init()
style_screen1_label_4_main_main_default.set_radius(10)
style_screen1_label_4_main_main_default.set_bg_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_4_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_4_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_4_main_main_default.set_bg_opa(255)
style_screen1_label_4_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_4_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_label_4_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_4_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_4_main_main_default.set_text_letter_space(2)
style_screen1_label_4_main_main_default.set_pad_left(0)
style_screen1_label_4_main_main_default.set_pad_right(0)
style_screen1_label_4_main_main_default.set_pad_top(0)
style_screen1_label_4_main_main_default.set_pad_bottom(0)

# add style for screen1_label_4
screen1_label_4.add_style(style_screen1_label_4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_5 = lv.label(screen1)
screen1_label_5.set_pos(22,178)
screen1_label_5.set_size(120,32)
screen1_label_5.set_text("体温")
screen1_label_5.set_long_mode(lv.label.LONG.WRAP)
screen1_label_5.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_5_main_main_default
style_screen1_label_5_main_main_default = lv.style_t()
style_screen1_label_5_main_main_default.init()
style_screen1_label_5_main_main_default.set_radius(10)
style_screen1_label_5_main_main_default.set_bg_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_5_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_5_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_5_main_main_default.set_bg_opa(255)
style_screen1_label_5_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_5_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_label_5_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_5_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_5_main_main_default.set_text_letter_space(2)
style_screen1_label_5_main_main_default.set_pad_left(0)
style_screen1_label_5_main_main_default.set_pad_right(0)
style_screen1_label_5_main_main_default.set_pad_top(0)
style_screen1_label_5_main_main_default.set_pad_bottom(0)

# add style for screen1_label_5
screen1_label_5.add_style(style_screen1_label_5_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_6 = lv.label(screen1)
screen1_label_6.set_pos(175,178)
screen1_label_6.set_size(120,32)
screen1_label_6.set_text("药品状态")
screen1_label_6.set_long_mode(lv.label.LONG.WRAP)
screen1_label_6.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_6_main_main_default
style_screen1_label_6_main_main_default = lv.style_t()
style_screen1_label_6_main_main_default.init()
style_screen1_label_6_main_main_default.set_radius(10)
style_screen1_label_6_main_main_default.set_bg_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_6_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_label_6_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_6_main_main_default.set_bg_opa(255)
style_screen1_label_6_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_6_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_label_6_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_6_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_6_main_main_default.set_text_letter_space(2)
style_screen1_label_6_main_main_default.set_pad_left(0)
style_screen1_label_6_main_main_default.set_pad_right(0)
style_screen1_label_6_main_main_default.set_pad_top(0)
style_screen1_label_6_main_main_default.set_pad_bottom(0)

# add style for screen1_label_6
screen1_label_6.add_style(style_screen1_label_6_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_digital_clock_1 = lv.label(screen1)
screen1_digital_clock_1.set_text("11:25:50")

class screen1_digital_clock_1_timerClass():
    def __init__(self):
        self.hour = 11
        self.minute = 25
        self.second = 50
  
    def count_24(self, timer):
        self.second += 1
        if self.second == 60:
            self.second = 0
            self.minute += 1
	
        if self.minute == 60:
            self.minute = 0
            self.hour +=1
            
        if self.hour == 24:
            self.hour = 0

        screen1_digital_clock_1.set_text("%02d:%02d:%02d" %(self.hour, self.minute, self.second))

    def count_12(self, timer):
        self.second += 1
        if self.second == 60:
            self.second = 0
            self.minute += 1
        if self.minute == 60:
            self.minute = 0
            if self.hour < 12:
                self.hour += 1
            else:
                self.hour += 1
                self.hour = self.hour % 12
        if (self.hour == 12 and self.second == 0 and self.minute == 0):
            if(self.meridiem == "PM"):
                self.meridiem == "AM"
            else:
                self.meridiem == "PM"
		
        screen1_digital_clock_1.set_text("%02d:%02d:%02d %s" %(self.hour, self.minute, self.second, self.meridiem))

screen1_digital_clock_1_timerInstance = screen1_digital_clock_1_timerClass()

screen1_digital_clock_1_timer = lv.timer_create_basic()
screen1_digital_clock_1_timer.set_period(1000)

screen1_digital_clock_1_timer.set_cb(lambda src: screen1_digital_clock_1_timerInstance.count_24(screen1_digital_clock_1_timer))


screen1_digital_clock_1.set_pos(89,25)
screen1_digital_clock_1.set_size(140,30)
# create style style_screen1_digital_clock_1_main_main_default
style_screen1_digital_clock_1_main_main_default = lv.style_t()
style_screen1_digital_clock_1_main_main_default.init()
style_screen1_digital_clock_1_main_main_default.set_radius(15)
style_screen1_digital_clock_1_main_main_default.set_bg_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_digital_clock_1_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen1_digital_clock_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_digital_clock_1_main_main_default.set_bg_opa(255)
style_screen1_digital_clock_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_digital_clock_1_main_main_default.set_text_font(lv.font_arial_14)
except AttributeError:
    try:
        style_screen1_digital_clock_1_main_main_default.set_text_font(lv.font_montserrat_14)
    except AttributeError:
        style_screen1_digital_clock_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_digital_clock_1_main_main_default.set_text_letter_space(0)
style_screen1_digital_clock_1_main_main_default.set_pad_left(0)
style_screen1_digital_clock_1_main_main_default.set_pad_right(0)
style_screen1_digital_clock_1_main_main_default.set_pad_top(0)
style_screen1_digital_clock_1_main_main_default.set_pad_bottom(0)

# add style for screen1_digital_clock_1
screen1_digital_clock_1.add_style(style_screen1_digital_clock_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_imgbtn_1 = lv.imgbtn(screen1)
screen1_imgbtn_1.set_pos(5,2)
screen1_imgbtn_1.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp291651182.png','rb') as f:
        screen1_imgbtn_1_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp291651182.png')
    sys.exit()

screen1_imgbtn_1_imgReleased = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_1_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_1_imgReleased_data
})
screen1_imgbtn_1.set_src(lv.imgbtn.STATE.RELEASED, screen1_imgbtn_1_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1344327013.png','rb') as f:
        screen1_imgbtn_1_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1344327013.png')
    sys.exit()

screen1_imgbtn_1_imgPressed = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_1_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_1_imgPressed_data
})
screen1_imgbtn_1.set_src(lv.imgbtn.STATE.PRESSED, screen1_imgbtn_1_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp291651182.png','rb') as f:
        screen1_imgbtn_1_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp291651182.png')
    sys.exit()

screen1_imgbtn_1_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_1_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_1_imgCheckedReleased_data
})
screen1_imgbtn_1.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen1_imgbtn_1_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1344327013.png','rb') as f:
        screen1_imgbtn_1_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1344327013.png')
    sys.exit()

screen1_imgbtn_1_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_1_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_1_imgCheckedPressed_data
})
screen1_imgbtn_1.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen1_imgbtn_1_imgCheckedPressed, None, None)

screen1_imgbtn_1.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen1_imgbtn_1_main_main_default
style_screen1_imgbtn_1_main_main_default = lv.style_t()
style_screen1_imgbtn_1_main_main_default.init()
style_screen1_imgbtn_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_imgbtn_1_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_imgbtn_1_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_imgbtn_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_imgbtn_1_main_main_default.set_img_recolor_opa(0)
style_screen1_imgbtn_1_main_main_default.set_img_opa(255)

# add style for screen1_imgbtn_1
screen1_imgbtn_1.add_style(style_screen1_imgbtn_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen1_imgbtn_1_main_main_pressed
style_screen1_imgbtn_1_main_main_pressed = lv.style_t()
style_screen1_imgbtn_1_main_main_pressed.init()
style_screen1_imgbtn_1_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen1_imgbtn_1_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen1_imgbtn_1_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen1_imgbtn_1_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_1_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen1_imgbtn_1_main_main_pressed.set_img_recolor_opa(0)

# add style for screen1_imgbtn_1
screen1_imgbtn_1.add_style(style_screen1_imgbtn_1_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen1_imgbtn_1_main_main_checked
style_screen1_imgbtn_1_main_main_checked = lv.style_t()
style_screen1_imgbtn_1_main_main_checked.init()
style_screen1_imgbtn_1_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen1_imgbtn_1_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen1_imgbtn_1_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen1_imgbtn_1_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_1_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen1_imgbtn_1_main_main_checked.set_img_recolor_opa(0)

# add style for screen1_imgbtn_1
screen1_imgbtn_1.add_style(style_screen1_imgbtn_1_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen1_img_1 = lv.img(screen1)
screen1_img_1.set_pos(95,28)
screen1_img_1.set_size(24,24)
screen1_img_1.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-928932038.png','rb') as f:
        screen1_img_1_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-928932038.png')
    sys.exit()

screen1_img_1_img = lv.img_dsc_t({
  'data_size': len(screen1_img_1_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_1_img_data
})

screen1_img_1.set_src(screen1_img_1_img)
screen1_img_1.set_pivot(0,0)
screen1_img_1.set_angle(0)
# create style style_screen1_img_1_main_main_default
style_screen1_img_1_main_main_default = lv.style_t()
style_screen1_img_1_main_main_default.init()
style_screen1_img_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_1_main_main_default.set_img_recolor_opa(0)
style_screen1_img_1_main_main_default.set_img_opa(255)

# add style for screen1_img_1
screen1_img_1.add_style(style_screen1_img_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_img_2 = lv.img(screen1)
screen1_img_2.set_pos(32,80)
screen1_img_2.set_size(24,24)
screen1_img_2.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp689227907.png','rb') as f:
        screen1_img_2_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp689227907.png')
    sys.exit()

screen1_img_2_img = lv.img_dsc_t({
  'data_size': len(screen1_img_2_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_2_img_data
})

screen1_img_2.set_src(screen1_img_2_img)
screen1_img_2.set_pivot(0,0)
screen1_img_2.set_angle(0)
# create style style_screen1_img_2_main_main_default
style_screen1_img_2_main_main_default = lv.style_t()
style_screen1_img_2_main_main_default.init()
style_screen1_img_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_2_main_main_default.set_img_recolor_opa(0)
style_screen1_img_2_main_main_default.set_img_opa(255)

# add style for screen1_img_2
screen1_img_2.add_style(style_screen1_img_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_img_3 = lv.img(screen1)
screen1_img_3.set_pos(186,83)
screen1_img_3.set_size(24,24)
screen1_img_3.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1521095302.png','rb') as f:
        screen1_img_3_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1521095302.png')
    sys.exit()

screen1_img_3_img = lv.img_dsc_t({
  'data_size': len(screen1_img_3_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_3_img_data
})

screen1_img_3.set_src(screen1_img_3_img)
screen1_img_3.set_pivot(0,0)
screen1_img_3.set_angle(0)
# create style style_screen1_img_3_main_main_default
style_screen1_img_3_main_main_default = lv.style_t()
style_screen1_img_3_main_main_default.init()
style_screen1_img_3_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_3_main_main_default.set_img_recolor_opa(0)
style_screen1_img_3_main_main_default.set_img_opa(255)

# add style for screen1_img_3
screen1_img_3.add_style(style_screen1_img_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_img_4 = lv.img(screen1)
screen1_img_4.set_pos(32,129)
screen1_img_4.set_size(24,24)
screen1_img_4.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-574283707.png','rb') as f:
        screen1_img_4_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-574283707.png')
    sys.exit()

screen1_img_4_img = lv.img_dsc_t({
  'data_size': len(screen1_img_4_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_4_img_data
})

screen1_img_4.set_src(screen1_img_4_img)
screen1_img_4.set_pivot(0,0)
screen1_img_4.set_angle(0)
# create style style_screen1_img_4_main_main_default
style_screen1_img_4_main_main_default = lv.style_t()
style_screen1_img_4_main_main_default.init()
style_screen1_img_4_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_4_main_main_default.set_img_recolor_opa(0)
style_screen1_img_4_main_main_default.set_img_opa(255)

# add style for screen1_img_4
screen1_img_4.add_style(style_screen1_img_4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_img_5 = lv.img(screen1)
screen1_img_5.set_pos(186,133)
screen1_img_5.set_size(24,24)
screen1_img_5.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-375752070.png','rb') as f:
        screen1_img_5_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-375752070.png')
    sys.exit()

screen1_img_5_img = lv.img_dsc_t({
  'data_size': len(screen1_img_5_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_5_img_data
})

screen1_img_5.set_src(screen1_img_5_img)
screen1_img_5.set_pivot(0,0)
screen1_img_5.set_angle(0)
# create style style_screen1_img_5_main_main_default
style_screen1_img_5_main_main_default = lv.style_t()
style_screen1_img_5_main_main_default.init()
style_screen1_img_5_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_5_main_main_default.set_img_recolor_opa(0)
style_screen1_img_5_main_main_default.set_img_opa(255)

# add style for screen1_img_5
screen1_img_5.add_style(style_screen1_img_5_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_img_6 = lv.img(screen1)
screen1_img_6.set_pos(32,182)
screen1_img_6.set_size(24,24)
screen1_img_6.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1124442992.png','rb') as f:
        screen1_img_6_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1124442992.png')
    sys.exit()

screen1_img_6_img = lv.img_dsc_t({
  'data_size': len(screen1_img_6_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_6_img_data
})

screen1_img_6.set_src(screen1_img_6_img)
screen1_img_6.set_pivot(0,0)
screen1_img_6.set_angle(0)
# create style style_screen1_img_6_main_main_default
style_screen1_img_6_main_main_default = lv.style_t()
style_screen1_img_6_main_main_default.init()
style_screen1_img_6_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_6_main_main_default.set_img_recolor_opa(0)
style_screen1_img_6_main_main_default.set_img_opa(255)

# add style for screen1_img_6
screen1_img_6.add_style(style_screen1_img_6_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_img_7 = lv.img(screen1)
screen1_img_7.set_pos(186,182)
screen1_img_7.set_size(24,24)
screen1_img_7.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp35628124.png','rb') as f:
        screen1_img_7_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp35628124.png')
    sys.exit()

screen1_img_7_img = lv.img_dsc_t({
  'data_size': len(screen1_img_7_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_img_7_img_data
})

screen1_img_7.set_src(screen1_img_7_img)
screen1_img_7.set_pivot(0,0)
screen1_img_7.set_angle(0)
# create style style_screen1_img_7_main_main_default
style_screen1_img_7_main_main_default = lv.style_t()
style_screen1_img_7_main_main_default.init()
style_screen1_img_7_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_img_7_main_main_default.set_img_recolor_opa(0)
style_screen1_img_7_main_main_default.set_img_opa(255)

# add style for screen1_img_7
screen1_img_7.add_style(style_screen1_img_7_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_7 = lv.label(screen1)
screen1_label_7.set_pos(33,90)
screen1_label_7.set_size(100,20)
screen1_label_7.set_text("none")
screen1_label_7.set_long_mode(lv.label.LONG.WRAP)
screen1_label_7.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_7_main_main_default
style_screen1_label_7_main_main_default = lv.style_t()
style_screen1_label_7_main_main_default.init()
style_screen1_label_7_main_main_default.set_radius(0)
style_screen1_label_7_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_7_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_7_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_7_main_main_default.set_bg_opa(0)
style_screen1_label_7_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_7_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen1_label_7_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen1_label_7_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_7_main_main_default.set_text_letter_space(2)
style_screen1_label_7_main_main_default.set_pad_left(0)
style_screen1_label_7_main_main_default.set_pad_right(0)
style_screen1_label_7_main_main_default.set_pad_top(0)
style_screen1_label_7_main_main_default.set_pad_bottom(0)

# add style for screen1_label_7
screen1_label_7.add_style(style_screen1_label_7_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_8 = lv.label(screen1)
screen1_label_8.set_pos(189,92)
screen1_label_8.set_size(100,20)
screen1_label_8.set_text("none")
screen1_label_8.set_long_mode(lv.label.LONG.WRAP)
screen1_label_8.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_8_main_main_default
style_screen1_label_8_main_main_default = lv.style_t()
style_screen1_label_8_main_main_default.init()
style_screen1_label_8_main_main_default.set_radius(0)
style_screen1_label_8_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_8_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_8_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_8_main_main_default.set_bg_opa(0)
style_screen1_label_8_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_8_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen1_label_8_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen1_label_8_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_8_main_main_default.set_text_letter_space(2)
style_screen1_label_8_main_main_default.set_pad_left(0)
style_screen1_label_8_main_main_default.set_pad_right(0)
style_screen1_label_8_main_main_default.set_pad_top(0)
style_screen1_label_8_main_main_default.set_pad_bottom(0)

# add style for screen1_label_8
screen1_label_8.add_style(style_screen1_label_8_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_9 = lv.label(screen1)
screen1_label_9.set_pos(37,136)
screen1_label_9.set_size(100,20)
screen1_label_9.set_text("none")
screen1_label_9.set_long_mode(lv.label.LONG.WRAP)
screen1_label_9.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_9_main_main_default
style_screen1_label_9_main_main_default = lv.style_t()
style_screen1_label_9_main_main_default.init()
style_screen1_label_9_main_main_default.set_radius(0)
style_screen1_label_9_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_9_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_9_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_9_main_main_default.set_bg_opa(0)
style_screen1_label_9_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_9_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen1_label_9_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen1_label_9_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_9_main_main_default.set_text_letter_space(2)
style_screen1_label_9_main_main_default.set_pad_left(0)
style_screen1_label_9_main_main_default.set_pad_right(0)
style_screen1_label_9_main_main_default.set_pad_top(0)
style_screen1_label_9_main_main_default.set_pad_bottom(0)

# add style for screen1_label_9
screen1_label_9.add_style(style_screen1_label_9_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_10 = lv.label(screen1)
screen1_label_10.set_pos(190,140)
screen1_label_10.set_size(100,20)
screen1_label_10.set_text("none")
screen1_label_10.set_long_mode(lv.label.LONG.WRAP)
screen1_label_10.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_10_main_main_default
style_screen1_label_10_main_main_default = lv.style_t()
style_screen1_label_10_main_main_default.init()
style_screen1_label_10_main_main_default.set_radius(0)
style_screen1_label_10_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_10_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_10_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_10_main_main_default.set_bg_opa(0)
style_screen1_label_10_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_10_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen1_label_10_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen1_label_10_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_10_main_main_default.set_text_letter_space(2)
style_screen1_label_10_main_main_default.set_pad_left(0)
style_screen1_label_10_main_main_default.set_pad_right(0)
style_screen1_label_10_main_main_default.set_pad_top(0)
style_screen1_label_10_main_main_default.set_pad_bottom(0)

# add style for screen1_label_10
screen1_label_10.add_style(style_screen1_label_10_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_11 = lv.label(screen1)
screen1_label_11.set_pos(33,190)
screen1_label_11.set_size(100,20)
screen1_label_11.set_text("none")
screen1_label_11.set_long_mode(lv.label.LONG.WRAP)
screen1_label_11.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_11_main_main_default
style_screen1_label_11_main_main_default = lv.style_t()
style_screen1_label_11_main_main_default.init()
style_screen1_label_11_main_main_default.set_radius(0)
style_screen1_label_11_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_11_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_11_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_11_main_main_default.set_bg_opa(0)
style_screen1_label_11_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_11_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen1_label_11_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen1_label_11_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_11_main_main_default.set_text_letter_space(2)
style_screen1_label_11_main_main_default.set_pad_left(0)
style_screen1_label_11_main_main_default.set_pad_right(0)
style_screen1_label_11_main_main_default.set_pad_top(0)
style_screen1_label_11_main_main_default.set_pad_bottom(0)

# add style for screen1_label_11
screen1_label_11.add_style(style_screen1_label_11_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_label_12 = lv.label(screen1)
screen1_label_12.set_pos(186,190)
screen1_label_12.set_size(100,20)
screen1_label_12.set_text("none")
screen1_label_12.set_long_mode(lv.label.LONG.WRAP)
screen1_label_12.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_12_main_main_default
style_screen1_label_12_main_main_default = lv.style_t()
style_screen1_label_12_main_main_default.init()
style_screen1_label_12_main_main_default.set_radius(0)
style_screen1_label_12_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_12_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_12_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_12_main_main_default.set_bg_opa(0)
style_screen1_label_12_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_12_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen1_label_12_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen1_label_12_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_12_main_main_default.set_text_letter_space(2)
style_screen1_label_12_main_main_default.set_pad_left(0)
style_screen1_label_12_main_main_default.set_pad_right(0)
style_screen1_label_12_main_main_default.set_pad_top(0)
style_screen1_label_12_main_main_default.set_pad_bottom(0)

# add style for screen1_label_12
screen1_label_12.add_style(style_screen1_label_12_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_imgbtn_2 = lv.imgbtn(screen1)
screen1_imgbtn_2.set_pos(284,5)
screen1_imgbtn_2.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1619538400.png','rb') as f:
        screen1_imgbtn_2_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1619538400.png')
    sys.exit()

screen1_imgbtn_2_imgReleased = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_2_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_2_imgReleased_data
})
screen1_imgbtn_2.set_src(lv.imgbtn.STATE.RELEASED, screen1_imgbtn_2_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1619538400.png','rb') as f:
        screen1_imgbtn_2_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1619538400.png')
    sys.exit()

screen1_imgbtn_2_imgPressed = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_2_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_2_imgPressed_data
})
screen1_imgbtn_2.set_src(lv.imgbtn.STATE.PRESSED, screen1_imgbtn_2_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1619538400.png','rb') as f:
        screen1_imgbtn_2_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1619538400.png')
    sys.exit()

screen1_imgbtn_2_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_2_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_2_imgCheckedReleased_data
})
screen1_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen1_imgbtn_2_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1574901596.png','rb') as f:
        screen1_imgbtn_2_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1574901596.png')
    sys.exit()

screen1_imgbtn_2_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen1_imgbtn_2_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen1_imgbtn_2_imgCheckedPressed_data
})
screen1_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen1_imgbtn_2_imgCheckedPressed, None, None)

screen1_imgbtn_2.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen1_imgbtn_2_main_main_default
style_screen1_imgbtn_2_main_main_default = lv.style_t()
style_screen1_imgbtn_2_main_main_default.init()
style_screen1_imgbtn_2_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_imgbtn_2_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_imgbtn_2_main_main_default.set_img_recolor_opa(0)
style_screen1_imgbtn_2_main_main_default.set_img_opa(255)

# add style for screen1_imgbtn_2
screen1_imgbtn_2.add_style(style_screen1_imgbtn_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen1_imgbtn_2_main_main_pressed
style_screen1_imgbtn_2_main_main_pressed = lv.style_t()
style_screen1_imgbtn_2_main_main_pressed.init()
style_screen1_imgbtn_2_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen1_imgbtn_2_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen1_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen1_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_2_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen1_imgbtn_2_main_main_pressed.set_img_recolor_opa(0)

# add style for screen1_imgbtn_2
screen1_imgbtn_2.add_style(style_screen1_imgbtn_2_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen1_imgbtn_2_main_main_checked
style_screen1_imgbtn_2_main_main_checked = lv.style_t()
style_screen1_imgbtn_2_main_main_checked.init()
style_screen1_imgbtn_2_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen1_imgbtn_2_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen1_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen1_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_2_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen1_imgbtn_2_main_main_checked.set_img_recolor_opa(0)

# add style for screen1_imgbtn_2
screen1_imgbtn_2.add_style(style_screen1_imgbtn_2_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen1_label_13 = lv.label(screen1)
screen1_label_13.set_pos(114,41)
screen1_label_13.set_size(100,11)
screen1_label_13.set_text("2022.8.12")
screen1_label_13.set_long_mode(lv.label.LONG.WRAP)
screen1_label_13.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen1_label_13_main_main_default
style_screen1_label_13_main_main_default = lv.style_t()
style_screen1_label_13_main_main_default.init()
style_screen1_label_13_main_main_default.set_radius(0)
style_screen1_label_13_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_13_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen1_label_13_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen1_label_13_main_main_default.set_bg_opa(0)
style_screen1_label_13_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_label_13_main_main_default.set_text_font(lv.font_arial_12)
except AttributeError:
    try:
        style_screen1_label_13_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_label_13_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_label_13_main_main_default.set_text_letter_space(2)
style_screen1_label_13_main_main_default.set_pad_left(0)
style_screen1_label_13_main_main_default.set_pad_right(0)
style_screen1_label_13_main_main_default.set_pad_top(0)
style_screen1_label_13_main_main_default.set_pad_bottom(0)

# add style for screen1_label_13
screen1_label_13.add_style(style_screen1_label_13_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen1_imgbtn_3 = lv.imgbtn(screen1)
screen1_imgbtn_3.set_pos(111,24)
screen1_imgbtn_3.set_size(100,31)





screen1_imgbtn_3.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen1_imgbtn_3_main_main_default
style_screen1_imgbtn_3_main_main_default = lv.style_t()
style_screen1_imgbtn_3_main_main_default.init()
style_screen1_imgbtn_3_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen1_imgbtn_3_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen1_imgbtn_3_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen1_imgbtn_3_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_3_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen1_imgbtn_3_main_main_default.set_img_recolor_opa(0)
style_screen1_imgbtn_3_main_main_default.set_img_opa(255)

# add style for screen1_imgbtn_3
screen1_imgbtn_3.add_style(style_screen1_imgbtn_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen1_imgbtn_3_main_main_pressed
style_screen1_imgbtn_3_main_main_pressed = lv.style_t()
style_screen1_imgbtn_3_main_main_pressed.init()
style_screen1_imgbtn_3_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen1_imgbtn_3_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen1_imgbtn_3_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen1_imgbtn_3_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_3_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen1_imgbtn_3_main_main_pressed.set_img_recolor_opa(0)

# add style for screen1_imgbtn_3
screen1_imgbtn_3.add_style(style_screen1_imgbtn_3_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen1_imgbtn_3_main_main_checked
style_screen1_imgbtn_3_main_main_checked = lv.style_t()
style_screen1_imgbtn_3_main_main_checked.init()
style_screen1_imgbtn_3_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen1_imgbtn_3_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen1_imgbtn_3_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen1_imgbtn_3_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen1_imgbtn_3_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen1_imgbtn_3_main_main_checked.set_img_recolor_opa(0)

# add style for screen1_imgbtn_3
screen1_imgbtn_3.add_style(style_screen1_imgbtn_3_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen2 = lv.obj()
# create style style_screen2_main_main_default
style_screen2_main_main_default = lv.style_t()
style_screen2_main_main_default.init()
style_screen2_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen2_main_main_default.set_bg_opa(0)

# add style for screen2
screen2.add_style(style_screen2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen2_btn_1 = lv.btn(screen2)
screen2_btn_1.set_pos(110,28)
screen2_btn_1.set_size(100,30)
screen2_btn_1_label = lv.label(screen2_btn_1)
screen2_btn_1_label.set_text("patient")
screen2_btn_1.set_style_pad_all(0, lv.STATE.DEFAULT)
screen2_btn_1_label.align(lv.ALIGN.CENTER,0,0)
screen2_btn_1_label.set_style_text_color(lv.color_make(0x00,0x00,0x00), lv.STATE.DEFAULT)
try:
    screen2_btn_1_label.set_style_text_font(lv.font_arial_12, lv.STATE.DEFAULT)
except AttributeError:
    try:
        screen2_btn_1_label.set_style_text_font(lv.font_montserrat_12, lv.STATE.DEFAULT)
    except AttributeError:
        screen2_btn_1_label.set_style_text_font(lv.font_montserrat_16, lv.STATE.DEFAULT)
# create style style_screen2_btn_1_main_main_default
style_screen2_btn_1_main_main_default = lv.style_t()
style_screen2_btn_1_main_main_default.init()
style_screen2_btn_1_main_main_default.set_radius(10)
style_screen2_btn_1_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_1_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen2_btn_1_main_main_default.set_bg_opa(255)
style_screen2_btn_1_main_main_default.set_shadow_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_1_main_main_default.set_shadow_opa(255)
style_screen2_btn_1_main_main_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_1_main_main_default.set_border_width(0)
style_screen2_btn_1_main_main_default.set_border_opa(255)

# add style for screen2_btn_1
screen2_btn_1.add_style(style_screen2_btn_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen2_btn_2 = lv.btn(screen2)
screen2_btn_2.set_pos(110,83)
screen2_btn_2.set_size(100,30)
screen2_btn_2_label = lv.label(screen2_btn_2)
screen2_btn_2_label.set_text("control")
screen2_btn_2.set_style_pad_all(0, lv.STATE.DEFAULT)
screen2_btn_2_label.align(lv.ALIGN.CENTER,0,0)
screen2_btn_2_label.set_style_text_color(lv.color_make(0x00,0x00,0x00), lv.STATE.DEFAULT)
try:
    screen2_btn_2_label.set_style_text_font(lv.font_arial_12, lv.STATE.DEFAULT)
except AttributeError:
    try:
        screen2_btn_2_label.set_style_text_font(lv.font_montserrat_12, lv.STATE.DEFAULT)
    except AttributeError:
        screen2_btn_2_label.set_style_text_font(lv.font_montserrat_16, lv.STATE.DEFAULT)
# create style style_screen2_btn_2_main_main_default
style_screen2_btn_2_main_main_default = lv.style_t()
style_screen2_btn_2_main_main_default.init()
style_screen2_btn_2_main_main_default.set_radius(10)
style_screen2_btn_2_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_2_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_2_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen2_btn_2_main_main_default.set_bg_opa(255)
style_screen2_btn_2_main_main_default.set_shadow_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_2_main_main_default.set_shadow_opa(255)
style_screen2_btn_2_main_main_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_2_main_main_default.set_border_width(0)
style_screen2_btn_2_main_main_default.set_border_opa(255)

# add style for screen2_btn_2
screen2_btn_2.add_style(style_screen2_btn_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen2_btn_3 = lv.btn(screen2)
screen2_btn_3.set_pos(110,190)
screen2_btn_3.set_size(100,30)
screen2_btn_3_label = lv.label(screen2_btn_3)
screen2_btn_3_label.set_text("ours")
screen2_btn_3.set_style_pad_all(0, lv.STATE.DEFAULT)
screen2_btn_3_label.align(lv.ALIGN.CENTER,0,0)
screen2_btn_3_label.set_style_text_color(lv.color_make(0x00,0x00,0x00), lv.STATE.DEFAULT)
try:
    screen2_btn_3_label.set_style_text_font(lv.font_arial_12, lv.STATE.DEFAULT)
except AttributeError:
    try:
        screen2_btn_3_label.set_style_text_font(lv.font_montserrat_12, lv.STATE.DEFAULT)
    except AttributeError:
        screen2_btn_3_label.set_style_text_font(lv.font_montserrat_16, lv.STATE.DEFAULT)
# create style style_screen2_btn_3_main_main_default
style_screen2_btn_3_main_main_default = lv.style_t()
style_screen2_btn_3_main_main_default.init()
style_screen2_btn_3_main_main_default.set_radius(10)
style_screen2_btn_3_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_3_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_3_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen2_btn_3_main_main_default.set_bg_opa(255)
style_screen2_btn_3_main_main_default.set_shadow_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_3_main_main_default.set_shadow_opa(255)
style_screen2_btn_3_main_main_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_3_main_main_default.set_border_width(0)
style_screen2_btn_3_main_main_default.set_border_opa(255)

# add style for screen2_btn_3
screen2_btn_3.add_style(style_screen2_btn_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen2_imgbtn_2 = lv.imgbtn(screen2)
screen2_imgbtn_2.set_pos(5,6)
screen2_imgbtn_2.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen2_imgbtn_2_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen2_imgbtn_2_imgReleased = lv.img_dsc_t({
  'data_size': len(screen2_imgbtn_2_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen2_imgbtn_2_imgReleased_data
})
screen2_imgbtn_2.set_src(lv.imgbtn.STATE.RELEASED, screen2_imgbtn_2_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen2_imgbtn_2_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen2_imgbtn_2_imgPressed = lv.img_dsc_t({
  'data_size': len(screen2_imgbtn_2_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen2_imgbtn_2_imgPressed_data
})
screen2_imgbtn_2.set_src(lv.imgbtn.STATE.PRESSED, screen2_imgbtn_2_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen2_imgbtn_2_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen2_imgbtn_2_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen2_imgbtn_2_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen2_imgbtn_2_imgCheckedReleased_data
})
screen2_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen2_imgbtn_2_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen2_imgbtn_2_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen2_imgbtn_2_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen2_imgbtn_2_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen2_imgbtn_2_imgCheckedPressed_data
})
screen2_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen2_imgbtn_2_imgCheckedPressed, None, None)

screen2_imgbtn_2.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen2_imgbtn_2_main_main_default
style_screen2_imgbtn_2_main_main_default = lv.style_t()
style_screen2_imgbtn_2_main_main_default.init()
style_screen2_imgbtn_2_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen2_imgbtn_2_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen2_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen2_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen2_imgbtn_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen2_imgbtn_2_main_main_default.set_img_recolor_opa(0)
style_screen2_imgbtn_2_main_main_default.set_img_opa(255)

# add style for screen2_imgbtn_2
screen2_imgbtn_2.add_style(style_screen2_imgbtn_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen2_imgbtn_2_main_main_pressed
style_screen2_imgbtn_2_main_main_pressed = lv.style_t()
style_screen2_imgbtn_2_main_main_pressed.init()
style_screen2_imgbtn_2_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen2_imgbtn_2_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen2_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen2_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen2_imgbtn_2_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen2_imgbtn_2_main_main_pressed.set_img_recolor_opa(0)

# add style for screen2_imgbtn_2
screen2_imgbtn_2.add_style(style_screen2_imgbtn_2_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen2_imgbtn_2_main_main_checked
style_screen2_imgbtn_2_main_main_checked = lv.style_t()
style_screen2_imgbtn_2_main_main_checked.init()
style_screen2_imgbtn_2_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen2_imgbtn_2_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen2_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen2_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen2_imgbtn_2_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen2_imgbtn_2_main_main_checked.set_img_recolor_opa(0)

# add style for screen2_imgbtn_2
screen2_imgbtn_2.add_style(style_screen2_imgbtn_2_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen2_btn_4 = lv.btn(screen2)
screen2_btn_4.set_pos(110,136)
screen2_btn_4.set_size(100,30)
screen2_btn_4_label = lv.label(screen2_btn_4)
screen2_btn_4_label.set_text("set")
screen2_btn_4.set_style_pad_all(0, lv.STATE.DEFAULT)
screen2_btn_4_label.align(lv.ALIGN.CENTER,0,0)
screen2_btn_4_label.set_style_text_color(lv.color_make(0x00,0x00,0x00), lv.STATE.DEFAULT)
try:
    screen2_btn_4_label.set_style_text_font(lv.font_arial_12, lv.STATE.DEFAULT)
except AttributeError:
    try:
        screen2_btn_4_label.set_style_text_font(lv.font_montserrat_12, lv.STATE.DEFAULT)
    except AttributeError:
        screen2_btn_4_label.set_style_text_font(lv.font_montserrat_16, lv.STATE.DEFAULT)
# create style style_screen2_btn_4_main_main_default
style_screen2_btn_4_main_main_default = lv.style_t()
style_screen2_btn_4_main_main_default.init()
style_screen2_btn_4_main_main_default.set_radius(10)
style_screen2_btn_4_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_4_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_4_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen2_btn_4_main_main_default.set_bg_opa(255)
style_screen2_btn_4_main_main_default.set_shadow_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_4_main_main_default.set_shadow_opa(255)
style_screen2_btn_4_main_main_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen2_btn_4_main_main_default.set_border_width(0)
style_screen2_btn_4_main_main_default.set_border_opa(255)

# add style for screen2_btn_4
screen2_btn_4.add_style(style_screen2_btn_4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen3 = lv.obj()
# create style style_screen3_main_main_default
style_screen3_main_main_default = lv.style_t()
style_screen3_main_main_default.init()
style_screen3_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen3_main_main_default.set_bg_opa(0)

# add style for screen3
screen3.add_style(style_screen3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen3_imgbtn_1 = lv.imgbtn(screen3)
screen3_imgbtn_1.set_pos(5,6)
screen3_imgbtn_1.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen3_imgbtn_1_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen3_imgbtn_1_imgReleased = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_1_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_1_imgReleased_data
})
screen3_imgbtn_1.set_src(lv.imgbtn.STATE.RELEASED, screen3_imgbtn_1_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen3_imgbtn_1_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen3_imgbtn_1_imgPressed = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_1_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_1_imgPressed_data
})
screen3_imgbtn_1.set_src(lv.imgbtn.STATE.PRESSED, screen3_imgbtn_1_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen3_imgbtn_1_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen3_imgbtn_1_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_1_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_1_imgCheckedReleased_data
})
screen3_imgbtn_1.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen3_imgbtn_1_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen3_imgbtn_1_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen3_imgbtn_1_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_1_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_1_imgCheckedPressed_data
})
screen3_imgbtn_1.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen3_imgbtn_1_imgCheckedPressed, None, None)

screen3_imgbtn_1.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen3_imgbtn_1_main_main_default
style_screen3_imgbtn_1_main_main_default = lv.style_t()
style_screen3_imgbtn_1_main_main_default.init()
style_screen3_imgbtn_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen3_imgbtn_1_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen3_imgbtn_1_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen3_imgbtn_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen3_imgbtn_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen3_imgbtn_1_main_main_default.set_img_recolor_opa(0)
style_screen3_imgbtn_1_main_main_default.set_img_opa(255)

# add style for screen3_imgbtn_1
screen3_imgbtn_1.add_style(style_screen3_imgbtn_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen3_imgbtn_1_main_main_pressed
style_screen3_imgbtn_1_main_main_pressed = lv.style_t()
style_screen3_imgbtn_1_main_main_pressed.init()
style_screen3_imgbtn_1_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen3_imgbtn_1_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen3_imgbtn_1_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen3_imgbtn_1_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen3_imgbtn_1_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen3_imgbtn_1_main_main_pressed.set_img_recolor_opa(0)

# add style for screen3_imgbtn_1
screen3_imgbtn_1.add_style(style_screen3_imgbtn_1_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen3_imgbtn_1_main_main_checked
style_screen3_imgbtn_1_main_main_checked = lv.style_t()
style_screen3_imgbtn_1_main_main_checked.init()
style_screen3_imgbtn_1_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen3_imgbtn_1_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen3_imgbtn_1_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen3_imgbtn_1_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen3_imgbtn_1_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen3_imgbtn_1_main_main_checked.set_img_recolor_opa(0)

# add style for screen3_imgbtn_1
screen3_imgbtn_1.add_style(style_screen3_imgbtn_1_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen3_imgbtn_2 = lv.imgbtn(screen3)
screen3_imgbtn_2.set_pos(102,4)
screen3_imgbtn_2.set_size(100,50)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1632565191.png','rb') as f:
        screen3_imgbtn_2_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1632565191.png')
    sys.exit()

screen3_imgbtn_2_imgReleased = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_2_imgReleased_data),
  'header': {'always_zero': 0, 'w': 100, 'h': 50, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_2_imgReleased_data
})
screen3_imgbtn_2.set_src(lv.imgbtn.STATE.RELEASED, screen3_imgbtn_2_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1956293502.png','rb') as f:
        screen3_imgbtn_2_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1956293502.png')
    sys.exit()

screen3_imgbtn_2_imgPressed = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_2_imgPressed_data),
  'header': {'always_zero': 0, 'w': 100, 'h': 50, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_2_imgPressed_data
})
screen3_imgbtn_2.set_src(lv.imgbtn.STATE.PRESSED, screen3_imgbtn_2_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1632565191.png','rb') as f:
        screen3_imgbtn_2_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1632565191.png')
    sys.exit()

screen3_imgbtn_2_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_2_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 100, 'h': 50, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_2_imgCheckedReleased_data
})
screen3_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen3_imgbtn_2_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1956293502.png','rb') as f:
        screen3_imgbtn_2_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1956293502.png')
    sys.exit()

screen3_imgbtn_2_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen3_imgbtn_2_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 100, 'h': 50, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen3_imgbtn_2_imgCheckedPressed_data
})
screen3_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen3_imgbtn_2_imgCheckedPressed, None, None)

screen3_imgbtn_2.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen3_imgbtn_2_main_main_default
style_screen3_imgbtn_2_main_main_default = lv.style_t()
style_screen3_imgbtn_2_main_main_default.init()
style_screen3_imgbtn_2_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen3_imgbtn_2_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen3_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen3_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen3_imgbtn_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen3_imgbtn_2_main_main_default.set_img_recolor_opa(0)
style_screen3_imgbtn_2_main_main_default.set_img_opa(255)

# add style for screen3_imgbtn_2
screen3_imgbtn_2.add_style(style_screen3_imgbtn_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen3_imgbtn_2_main_main_pressed
style_screen3_imgbtn_2_main_main_pressed = lv.style_t()
style_screen3_imgbtn_2_main_main_pressed.init()
style_screen3_imgbtn_2_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen3_imgbtn_2_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen3_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen3_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen3_imgbtn_2_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen3_imgbtn_2_main_main_pressed.set_img_recolor_opa(0)

# add style for screen3_imgbtn_2
screen3_imgbtn_2.add_style(style_screen3_imgbtn_2_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen3_imgbtn_2_main_main_checked
style_screen3_imgbtn_2_main_main_checked = lv.style_t()
style_screen3_imgbtn_2_main_main_checked.init()
style_screen3_imgbtn_2_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen3_imgbtn_2_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen3_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen3_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen3_imgbtn_2_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen3_imgbtn_2_main_main_checked.set_img_recolor_opa(0)

# add style for screen3_imgbtn_2
screen3_imgbtn_2.add_style(style_screen3_imgbtn_2_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen3_ta_1 = lv.textarea(screen3)
screen3_ta_1.set_pos(62,62)
screen3_ta_1.set_size(200,22)
screen3_ta_1.set_text("number：")
try:
    screen3_kb
except NameError:
    screen3_kb = lv.keyboard(screen3)

screen3_kb.add_flag(lv.obj.FLAG.HIDDEN)
screen3_kb.set_textarea(screen3_ta_1)
screen3_ta_1.add_event_cb(lambda e: ta_event_cb(e,screen3_kb), lv.EVENT.ALL, None)
# create style style_screen3_ta_1_main_main_default
style_screen3_ta_1_main_main_default = lv.style_t()
style_screen3_ta_1_main_main_default.init()
style_screen3_ta_1_main_main_default.set_radius(4)
style_screen3_ta_1_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen3_ta_1_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen3_ta_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen3_ta_1_main_main_default.set_bg_opa(255)
style_screen3_ta_1_main_main_default.set_border_color(lv.color_make(0xe6,0xe6,0xe6))
style_screen3_ta_1_main_main_default.set_border_width(2)
style_screen3_ta_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen3_ta_1_main_main_default.set_text_font(lv.font_arial_12)
except AttributeError:
    try:
        style_screen3_ta_1_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen3_ta_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen3_ta_1_main_main_default.set_text_letter_space(2)
style_screen3_ta_1_main_main_default.set_text_align(lv.TEXT_ALIGN.LEFT)
style_screen3_ta_1_main_main_default.set_pad_left(2)
style_screen3_ta_1_main_main_default.set_pad_right(2)
style_screen3_ta_1_main_main_default.set_pad_top(2)
style_screen3_ta_1_main_main_default.set_pad_bottom(2)

# add style for screen3_ta_1
screen3_ta_1.add_style(style_screen3_ta_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen3_ta_1_main_scrollbar_default
style_screen3_ta_1_main_scrollbar_default = lv.style_t()
style_screen3_ta_1_main_scrollbar_default.init()
style_screen3_ta_1_main_scrollbar_default.set_radius(0)
style_screen3_ta_1_main_scrollbar_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen3_ta_1_main_scrollbar_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen3_ta_1_main_scrollbar_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen3_ta_1_main_scrollbar_default.set_bg_opa(255)

# add style for screen3_ta_1
screen3_ta_1.add_style(style_screen3_ta_1_main_scrollbar_default, lv.PART.SCROLLBAR|lv.STATE.DEFAULT)

screen4 = lv.obj()
# create style style_screen4_main_main_default
style_screen4_main_main_default = lv.style_t()
style_screen4_main_main_default.init()
style_screen4_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_main_main_default.set_bg_opa(0)

# add style for screen4
screen4.add_style(style_screen4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_imgbtn_2 = lv.imgbtn(screen4)
screen4_imgbtn_2.set_pos(4,6)
screen4_imgbtn_2.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen4_imgbtn_2_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen4_imgbtn_2_imgReleased = lv.img_dsc_t({
  'data_size': len(screen4_imgbtn_2_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_imgbtn_2_imgReleased_data
})
screen4_imgbtn_2.set_src(lv.imgbtn.STATE.RELEASED, screen4_imgbtn_2_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen4_imgbtn_2_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen4_imgbtn_2_imgPressed = lv.img_dsc_t({
  'data_size': len(screen4_imgbtn_2_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_imgbtn_2_imgPressed_data
})
screen4_imgbtn_2.set_src(lv.imgbtn.STATE.PRESSED, screen4_imgbtn_2_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen4_imgbtn_2_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen4_imgbtn_2_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen4_imgbtn_2_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_imgbtn_2_imgCheckedReleased_data
})
screen4_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen4_imgbtn_2_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen4_imgbtn_2_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen4_imgbtn_2_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen4_imgbtn_2_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_imgbtn_2_imgCheckedPressed_data
})
screen4_imgbtn_2.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen4_imgbtn_2_imgCheckedPressed, None, None)

screen4_imgbtn_2.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen4_imgbtn_2_main_main_default
style_screen4_imgbtn_2_main_main_default = lv.style_t()
style_screen4_imgbtn_2_main_main_default.init()
style_screen4_imgbtn_2_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_imgbtn_2_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_imgbtn_2_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_imgbtn_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_imgbtn_2_main_main_default.set_img_recolor_opa(0)
style_screen4_imgbtn_2_main_main_default.set_img_opa(255)

# add style for screen4_imgbtn_2
screen4_imgbtn_2.add_style(style_screen4_imgbtn_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_imgbtn_2_main_main_pressed
style_screen4_imgbtn_2_main_main_pressed = lv.style_t()
style_screen4_imgbtn_2_main_main_pressed.init()
style_screen4_imgbtn_2_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen4_imgbtn_2_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen4_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen4_imgbtn_2_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen4_imgbtn_2_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen4_imgbtn_2_main_main_pressed.set_img_recolor_opa(0)

# add style for screen4_imgbtn_2
screen4_imgbtn_2.add_style(style_screen4_imgbtn_2_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen4_imgbtn_2_main_main_checked
style_screen4_imgbtn_2_main_main_checked = lv.style_t()
style_screen4_imgbtn_2_main_main_checked.init()
style_screen4_imgbtn_2_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen4_imgbtn_2_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen4_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen4_imgbtn_2_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen4_imgbtn_2_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen4_imgbtn_2_main_main_checked.set_img_recolor_opa(0)

# add style for screen4_imgbtn_2
screen4_imgbtn_2.add_style(style_screen4_imgbtn_2_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen4_label_9 = lv.label(screen4)
screen4_label_9.set_pos(29,64)
screen4_label_9.set_size(120,31)
screen4_label_9.set_text("风扇")
screen4_label_9.set_long_mode(lv.label.LONG.WRAP)
screen4_label_9.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen4_label_9_main_main_default
style_screen4_label_9_main_main_default = lv.style_t()
style_screen4_label_9_main_main_default.init()
style_screen4_label_9_main_main_default.set_radius(10)
style_screen4_label_9_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen4_label_9_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen4_label_9_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_label_9_main_main_default.set_bg_opa(255)
style_screen4_label_9_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_label_9_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_label_9_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_label_9_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_label_9_main_main_default.set_text_letter_space(2)
style_screen4_label_9_main_main_default.set_pad_left(0)
style_screen4_label_9_main_main_default.set_pad_right(0)
style_screen4_label_9_main_main_default.set_pad_top(0)
style_screen4_label_9_main_main_default.set_pad_bottom(0)

# add style for screen4_label_9
screen4_label_9.add_style(style_screen4_label_9_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_label_10 = lv.label(screen4)
screen4_label_10.set_pos(170,64)
screen4_label_10.set_size(120,31)
screen4_label_10.set_text("消毒")
screen4_label_10.set_long_mode(lv.label.LONG.WRAP)
screen4_label_10.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen4_label_10_main_main_default
style_screen4_label_10_main_main_default = lv.style_t()
style_screen4_label_10_main_main_default.init()
style_screen4_label_10_main_main_default.set_radius(10)
style_screen4_label_10_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen4_label_10_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen4_label_10_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_label_10_main_main_default.set_bg_opa(255)
style_screen4_label_10_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_label_10_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_label_10_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_label_10_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_label_10_main_main_default.set_text_letter_space(2)
style_screen4_label_10_main_main_default.set_pad_left(0)
style_screen4_label_10_main_main_default.set_pad_right(0)
style_screen4_label_10_main_main_default.set_pad_top(0)
style_screen4_label_10_main_main_default.set_pad_bottom(0)

# add style for screen4_label_10
screen4_label_10.add_style(style_screen4_label_10_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_label_11 = lv.label(screen4)
screen4_label_11.set_pos(29,121)
screen4_label_11.set_size(120,31)
screen4_label_11.set_text("箱门")
screen4_label_11.set_long_mode(lv.label.LONG.WRAP)
screen4_label_11.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen4_label_11_main_main_default
style_screen4_label_11_main_main_default = lv.style_t()
style_screen4_label_11_main_main_default.init()
style_screen4_label_11_main_main_default.set_radius(10)
style_screen4_label_11_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen4_label_11_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen4_label_11_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_label_11_main_main_default.set_bg_opa(255)
style_screen4_label_11_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_label_11_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_label_11_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_label_11_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_label_11_main_main_default.set_text_letter_space(2)
style_screen4_label_11_main_main_default.set_pad_left(0)
style_screen4_label_11_main_main_default.set_pad_right(0)
style_screen4_label_11_main_main_default.set_pad_top(0)
style_screen4_label_11_main_main_default.set_pad_bottom(0)

# add style for screen4_label_11
screen4_label_11.add_style(style_screen4_label_11_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_label_12 = lv.label(screen4)
screen4_label_12.set_pos(170,119)
screen4_label_12.set_size(120,31)
screen4_label_12.set_text("警报")
screen4_label_12.set_long_mode(lv.label.LONG.WRAP)
screen4_label_12.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen4_label_12_main_main_default
style_screen4_label_12_main_main_default = lv.style_t()
style_screen4_label_12_main_main_default.init()
style_screen4_label_12_main_main_default.set_radius(10)
style_screen4_label_12_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen4_label_12_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen4_label_12_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_label_12_main_main_default.set_bg_opa(255)
style_screen4_label_12_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_label_12_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_label_12_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_label_12_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_label_12_main_main_default.set_text_letter_space(2)
style_screen4_label_12_main_main_default.set_pad_left(0)
style_screen4_label_12_main_main_default.set_pad_right(0)
style_screen4_label_12_main_main_default.set_pad_top(0)
style_screen4_label_12_main_main_default.set_pad_bottom(0)

# add style for screen4_label_12
screen4_label_12.add_style(style_screen4_label_12_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_sw_1 = lv.switch(screen4)
screen4_sw_1.set_pos(71,77)
screen4_sw_1.set_size(35,18)
# create style style_screen4_sw_1_main_main_default
style_screen4_sw_1_main_main_default = lv.style_t()
style_screen4_sw_1_main_main_default.init()
style_screen4_sw_1_main_main_default.set_radius(100)
style_screen4_sw_1_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_1_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_1_main_main_default.set_bg_opa(255)

# add style for screen4_sw_1
screen4_sw_1.add_style(style_screen4_sw_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_sw_1_main_indicator_checked
style_screen4_sw_1_main_indicator_checked = lv.style_t()
style_screen4_sw_1_main_indicator_checked.init()
style_screen4_sw_1_main_indicator_checked.set_radius(100)
style_screen4_sw_1_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_1_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_1_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_1_main_indicator_checked.set_bg_opa(255)

# add style for screen4_sw_1
screen4_sw_1.add_style(style_screen4_sw_1_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen4_sw_1_main_knob_default
style_screen4_sw_1_main_knob_default = lv.style_t()
style_screen4_sw_1_main_knob_default.init()
style_screen4_sw_1_main_knob_default.set_radius(100)
style_screen4_sw_1_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_1_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_1_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_1_main_knob_default.set_bg_opa(255)

# add style for screen4_sw_1
screen4_sw_1.add_style(style_screen4_sw_1_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen4_sw_2 = lv.switch(screen4)
screen4_sw_2.set_pos(208,77)
screen4_sw_2.set_size(35,18)
# create style style_screen4_sw_2_main_main_default
style_screen4_sw_2_main_main_default = lv.style_t()
style_screen4_sw_2_main_main_default.init()
style_screen4_sw_2_main_main_default.set_radius(100)
style_screen4_sw_2_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_2_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_2_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_2_main_main_default.set_bg_opa(255)

# add style for screen4_sw_2
screen4_sw_2.add_style(style_screen4_sw_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_sw_2_main_indicator_checked
style_screen4_sw_2_main_indicator_checked = lv.style_t()
style_screen4_sw_2_main_indicator_checked.init()
style_screen4_sw_2_main_indicator_checked.set_radius(100)
style_screen4_sw_2_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_2_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_2_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_2_main_indicator_checked.set_bg_opa(255)

# add style for screen4_sw_2
screen4_sw_2.add_style(style_screen4_sw_2_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen4_sw_2_main_knob_default
style_screen4_sw_2_main_knob_default = lv.style_t()
style_screen4_sw_2_main_knob_default.init()
style_screen4_sw_2_main_knob_default.set_radius(100)
style_screen4_sw_2_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_2_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_2_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_2_main_knob_default.set_bg_opa(255)

# add style for screen4_sw_2
screen4_sw_2.add_style(style_screen4_sw_2_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen4_sw_3 = lv.switch(screen4)
screen4_sw_3.set_pos(213,132)
screen4_sw_3.set_size(35,18)
# create style style_screen4_sw_3_main_main_default
style_screen4_sw_3_main_main_default = lv.style_t()
style_screen4_sw_3_main_main_default.init()
style_screen4_sw_3_main_main_default.set_radius(100)
style_screen4_sw_3_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_3_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_3_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_3_main_main_default.set_bg_opa(255)

# add style for screen4_sw_3
screen4_sw_3.add_style(style_screen4_sw_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_sw_3_main_indicator_checked
style_screen4_sw_3_main_indicator_checked = lv.style_t()
style_screen4_sw_3_main_indicator_checked.init()
style_screen4_sw_3_main_indicator_checked.set_radius(100)
style_screen4_sw_3_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_3_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_3_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_3_main_indicator_checked.set_bg_opa(255)

# add style for screen4_sw_3
screen4_sw_3.add_style(style_screen4_sw_3_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen4_sw_3_main_knob_default
style_screen4_sw_3_main_knob_default = lv.style_t()
style_screen4_sw_3_main_knob_default.init()
style_screen4_sw_3_main_knob_default.set_radius(100)
style_screen4_sw_3_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_3_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_3_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_3_main_knob_default.set_bg_opa(255)

# add style for screen4_sw_3
screen4_sw_3.add_style(style_screen4_sw_3_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen4_label_14 = lv.label(screen4)
screen4_label_14.set_pos(99,15)
screen4_label_14.set_size(120,31)
screen4_label_14.set_text("设备控制")
screen4_label_14.set_long_mode(lv.label.LONG.WRAP)
screen4_label_14.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen4_label_14_main_main_default
style_screen4_label_14_main_main_default = lv.style_t()
style_screen4_label_14_main_main_default.init()
style_screen4_label_14_main_main_default.set_radius(10)
style_screen4_label_14_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen4_label_14_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen4_label_14_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_label_14_main_main_default.set_bg_opa(255)
style_screen4_label_14_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_label_14_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_label_14_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_label_14_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_label_14_main_main_default.set_text_letter_space(2)
style_screen4_label_14_main_main_default.set_pad_left(0)
style_screen4_label_14_main_main_default.set_pad_right(0)
style_screen4_label_14_main_main_default.set_pad_top(0)
style_screen4_label_14_main_main_default.set_pad_bottom(0)

# add style for screen4_label_14
screen4_label_14.add_style(style_screen4_label_14_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_img_1 = lv.img(screen4)
screen4_img_1.set_pos(37,66)
screen4_img_1.set_size(24,24)
screen4_img_1.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-307063948.png','rb') as f:
        screen4_img_1_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-307063948.png')
    sys.exit()

screen4_img_1_img = lv.img_dsc_t({
  'data_size': len(screen4_img_1_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_img_1_img_data
})

screen4_img_1.set_src(screen4_img_1_img)
screen4_img_1.set_pivot(0,0)
screen4_img_1.set_angle(0)
# create style style_screen4_img_1_main_main_default
style_screen4_img_1_main_main_default = lv.style_t()
style_screen4_img_1_main_main_default.init()
style_screen4_img_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_img_1_main_main_default.set_img_recolor_opa(0)
style_screen4_img_1_main_main_default.set_img_opa(255)

# add style for screen4_img_1
screen4_img_1.add_style(style_screen4_img_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_img_2 = lv.img(screen4)
screen4_img_2.set_pos(177,68)
screen4_img_2.set_size(24,24)
screen4_img_2.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-886928741.png','rb') as f:
        screen4_img_2_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-886928741.png')
    sys.exit()

screen4_img_2_img = lv.img_dsc_t({
  'data_size': len(screen4_img_2_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_img_2_img_data
})

screen4_img_2.set_src(screen4_img_2_img)
screen4_img_2.set_pivot(0,0)
screen4_img_2.set_angle(0)
# create style style_screen4_img_2_main_main_default
style_screen4_img_2_main_main_default = lv.style_t()
style_screen4_img_2_main_main_default.init()
style_screen4_img_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_img_2_main_main_default.set_img_recolor_opa(0)
style_screen4_img_2_main_main_default.set_img_opa(255)

# add style for screen4_img_2
screen4_img_2.add_style(style_screen4_img_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_img_3 = lv.img(screen4)
screen4_img_3.set_pos(37,128)
screen4_img_3.set_size(24,24)
screen4_img_3.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp685162975.png','rb') as f:
        screen4_img_3_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp685162975.png')
    sys.exit()

screen4_img_3_img = lv.img_dsc_t({
  'data_size': len(screen4_img_3_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_img_3_img_data
})

screen4_img_3.set_src(screen4_img_3_img)
screen4_img_3.set_pivot(0,0)
screen4_img_3.set_angle(0)
# create style style_screen4_img_3_main_main_default
style_screen4_img_3_main_main_default = lv.style_t()
style_screen4_img_3_main_main_default.init()
style_screen4_img_3_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_img_3_main_main_default.set_img_recolor_opa(0)
style_screen4_img_3_main_main_default.set_img_opa(255)

# add style for screen4_img_3
screen4_img_3.add_style(style_screen4_img_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_img_4 = lv.img(screen4)
screen4_img_4.set_pos(177,124)
screen4_img_4.set_size(24,24)
screen4_img_4.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1082310934.png','rb') as f:
        screen4_img_4_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1082310934.png')
    sys.exit()

screen4_img_4_img = lv.img_dsc_t({
  'data_size': len(screen4_img_4_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_img_4_img_data
})

screen4_img_4.set_src(screen4_img_4_img)
screen4_img_4.set_pivot(0,0)
screen4_img_4.set_angle(0)
# create style style_screen4_img_4_main_main_default
style_screen4_img_4_main_main_default = lv.style_t()
style_screen4_img_4_main_main_default.init()
style_screen4_img_4_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_img_4_main_main_default.set_img_recolor_opa(0)
style_screen4_img_4_main_main_default.set_img_opa(255)

# add style for screen4_img_4
screen4_img_4.add_style(style_screen4_img_4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_img_5 = lv.img(screen4)
screen4_img_5.set_pos(104,21)
screen4_img_5.set_size(24,24)
screen4_img_5.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-106278344.png','rb') as f:
        screen4_img_5_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-106278344.png')
    sys.exit()

screen4_img_5_img = lv.img_dsc_t({
  'data_size': len(screen4_img_5_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_img_5_img_data
})

screen4_img_5.set_src(screen4_img_5_img)
screen4_img_5.set_pivot(0,0)
screen4_img_5.set_angle(0)
# create style style_screen4_img_5_main_main_default
style_screen4_img_5_main_main_default = lv.style_t()
style_screen4_img_5_main_main_default.init()
style_screen4_img_5_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_img_5_main_main_default.set_img_recolor_opa(0)
style_screen4_img_5_main_main_default.set_img_opa(255)

# add style for screen4_img_5
screen4_img_5.add_style(style_screen4_img_5_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_label_15 = lv.label(screen4)
screen4_label_15.set_pos(28,175)
screen4_label_15.set_size(120,31)
screen4_label_15.set_text("短信测试")
screen4_label_15.set_long_mode(lv.label.LONG.WRAP)
screen4_label_15.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen4_label_15_main_main_default
style_screen4_label_15_main_main_default = lv.style_t()
style_screen4_label_15_main_main_default.init()
style_screen4_label_15_main_main_default.set_radius(10)
style_screen4_label_15_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen4_label_15_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen4_label_15_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_label_15_main_main_default.set_bg_opa(255)
style_screen4_label_15_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_label_15_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_label_15_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_label_15_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_label_15_main_main_default.set_text_letter_space(2)
style_screen4_label_15_main_main_default.set_pad_left(0)
style_screen4_label_15_main_main_default.set_pad_right(0)
style_screen4_label_15_main_main_default.set_pad_top(0)
style_screen4_label_15_main_main_default.set_pad_bottom(0)

# add style for screen4_label_15
screen4_label_15.add_style(style_screen4_label_15_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_img_6 = lv.img(screen4)
screen4_img_6.set_pos(37,177)
screen4_img_6.set_size(24,24)
screen4_img_6.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp908859726.png','rb') as f:
        screen4_img_6_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp908859726.png')
    sys.exit()

screen4_img_6_img = lv.img_dsc_t({
  'data_size': len(screen4_img_6_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen4_img_6_img_data
})

screen4_img_6.set_src(screen4_img_6_img)
screen4_img_6.set_pivot(0,0)
screen4_img_6.set_angle(0)
# create style style_screen4_img_6_main_main_default
style_screen4_img_6_main_main_default = lv.style_t()
style_screen4_img_6_main_main_default.init()
style_screen4_img_6_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen4_img_6_main_main_default.set_img_recolor_opa(0)
style_screen4_img_6_main_main_default.set_img_opa(255)

# add style for screen4_img_6
screen4_img_6.add_style(style_screen4_img_6_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen4_spinbox_3 = lv.spinbox(screen4)
screen4_spinbox_3.set_pos(199,176)
screen4_spinbox_3.set_width(73)
screen4_spinbox_3.set_height(29)
screen4_spinbox_3.set_digit_format(4, 2)
screen4_spinbox_3.step_prev()
screen4_spinbox_3.set_range(-99999, 99999)

def screen4_spinbox_3_increment_event_cb(e):
	code = e.get_code()
	if code == lv.EVENT.SHORT_CLICKED or code == lv.EVENT.LONG_PRESSED_REPEAT:
		screen4_spinbox_3.increment()
def screen4_spinbox_3_decrement_event_cb(e):
	code = e.get_code()
	if code == lv.EVENT.SHORT_CLICKED or code == lv.EVENT.LONG_PRESSED_REPEAT:
		screen4_spinbox_3.decrement()

# create style style_screen4_spinbox_3_extra_btns_main_default
style_screen4_spinbox_3_extra_btns_main_default = lv.style_t()
style_screen4_spinbox_3_extra_btns_main_default.init()
style_screen4_spinbox_3_extra_btns_main_default.set_radius(5)
style_screen4_spinbox_3_extra_btns_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_spinbox_3_extra_btns_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_spinbox_3_extra_btns_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_spinbox_3_extra_btns_main_default.set_bg_opa(255)
style_screen4_spinbox_3_extra_btns_main_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_spinbox_3_extra_btns_main_default.set_border_width(0)
style_screen4_spinbox_3_extra_btns_main_default.set_text_color(lv.color_make(0xff,0xff,0xff))
try:
    style_screen4_spinbox_3_extra_btns_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_spinbox_3_extra_btns_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_spinbox_3_extra_btns_main_default.set_text_font(lv.font_montserrat_16)


screen4_spinbox_3_height = screen4_spinbox_3.get_height()
screen4_spinbox_3_btn = lv.btn(screen4)
screen4_spinbox_3_btn.set_size(screen4_spinbox_3_height, screen4_spinbox_3_height)
screen4_spinbox_3_btn.align_to(screen4_spinbox_3, lv.ALIGN.OUT_RIGHT_MID, 5, 0)
screen4_spinbox_3_btn.set_style_bg_img_src(lv.SYMBOL.PLUS, 0)
screen4_spinbox_3_btn.add_event_cb(screen4_spinbox_3_increment_event_cb, lv.EVENT.ALL, None)
screen4_spinbox_3_btn_minus = lv.btn(screen4)
screen4_spinbox_3_btn_minus.set_size(screen4_spinbox_3_height, screen4_spinbox_3_height)
screen4_spinbox_3_btn_minus.align_to(screen4_spinbox_3, lv.ALIGN.OUT_LEFT_MID, -5, 0)
screen4_spinbox_3_btn_minus.set_style_bg_img_src(lv.SYMBOL.MINUS, 0)
screen4_spinbox_3_btn_minus.add_event_cb(screen4_spinbox_3_decrement_event_cb, lv.EVENT.ALL, None)

# add style for screen4_spinbox_3_btn
screen4_spinbox_3_btn.add_style(style_screen4_spinbox_3_extra_btns_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)


# add style for screen4_spinbox_3_btn_minus
screen4_spinbox_3_btn_minus.add_style(style_screen4_spinbox_3_extra_btns_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_spinbox_3_main_main_default
style_screen4_spinbox_3_main_main_default = lv.style_t()
style_screen4_spinbox_3_main_main_default.init()
style_screen4_spinbox_3_main_main_default.set_radius(5)
style_screen4_spinbox_3_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_spinbox_3_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen4_spinbox_3_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_spinbox_3_main_main_default.set_bg_opa(255)
style_screen4_spinbox_3_main_main_default.set_border_color(lv.color_make(0xf0,0xf1,0xff))
style_screen4_spinbox_3_main_main_default.set_border_width(2)
style_screen4_spinbox_3_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen4_spinbox_3_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_spinbox_3_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_spinbox_3_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen4_spinbox_3_main_main_default.set_text_letter_space(0)
style_screen4_spinbox_3_main_main_default.set_pad_left(2)
style_screen4_spinbox_3_main_main_default.set_pad_right(0)
style_screen4_spinbox_3_main_main_default.set_pad_top(14)
style_screen4_spinbox_3_main_main_default.set_pad_bottom(14)

# add style for screen4_spinbox_3
screen4_spinbox_3.add_style(style_screen4_spinbox_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_spinbox_3_main_cursor_default
style_screen4_spinbox_3_main_cursor_default = lv.style_t()
style_screen4_spinbox_3_main_cursor_default.init()
style_screen4_spinbox_3_main_cursor_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_spinbox_3_main_cursor_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_spinbox_3_main_cursor_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_spinbox_3_main_cursor_default.set_bg_opa(255)
style_screen4_spinbox_3_main_cursor_default.set_text_color(lv.color_make(0xff,0xff,0xff))
try:
    style_screen4_spinbox_3_main_cursor_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen4_spinbox_3_main_cursor_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen4_spinbox_3_main_cursor_default.set_text_font(lv.font_montserrat_16)

# add style for screen4_spinbox_3
screen4_spinbox_3.add_style(style_screen4_spinbox_3_main_cursor_default, lv.PART.CURSOR|lv.STATE.DEFAULT)

screen4_sw_4 = lv.switch(screen4)
screen4_sw_4.set_pos(71,135)
screen4_sw_4.set_size(35,18)
# create style style_screen4_sw_4_main_main_default
style_screen4_sw_4_main_main_default = lv.style_t()
style_screen4_sw_4_main_main_default.init()
style_screen4_sw_4_main_main_default.set_radius(100)
style_screen4_sw_4_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_4_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_4_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_4_main_main_default.set_bg_opa(255)

# add style for screen4_sw_4
screen4_sw_4.add_style(style_screen4_sw_4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_sw_4_main_indicator_checked
style_screen4_sw_4_main_indicator_checked = lv.style_t()
style_screen4_sw_4_main_indicator_checked.init()
style_screen4_sw_4_main_indicator_checked.set_radius(100)
style_screen4_sw_4_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_4_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_4_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_4_main_indicator_checked.set_bg_opa(255)

# add style for screen4_sw_4
screen4_sw_4.add_style(style_screen4_sw_4_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen4_sw_4_main_knob_default
style_screen4_sw_4_main_knob_default = lv.style_t()
style_screen4_sw_4_main_knob_default.init()
style_screen4_sw_4_main_knob_default.set_radius(100)
style_screen4_sw_4_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_4_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_4_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_4_main_knob_default.set_bg_opa(255)

# add style for screen4_sw_4
screen4_sw_4.add_style(style_screen4_sw_4_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen4_sw_5 = lv.switch(screen4)
screen4_sw_5.set_pos(71,187)
screen4_sw_5.set_size(35,18)
# create style style_screen4_sw_5_main_main_default
style_screen4_sw_5_main_main_default = lv.style_t()
style_screen4_sw_5_main_main_default.init()
style_screen4_sw_5_main_main_default.set_radius(100)
style_screen4_sw_5_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_5_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen4_sw_5_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_5_main_main_default.set_bg_opa(255)

# add style for screen4_sw_5
screen4_sw_5.add_style(style_screen4_sw_5_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen4_sw_5_main_indicator_checked
style_screen4_sw_5_main_indicator_checked = lv.style_t()
style_screen4_sw_5_main_indicator_checked.init()
style_screen4_sw_5_main_indicator_checked.set_radius(100)
style_screen4_sw_5_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_5_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen4_sw_5_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_5_main_indicator_checked.set_bg_opa(255)

# add style for screen4_sw_5
screen4_sw_5.add_style(style_screen4_sw_5_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen4_sw_5_main_knob_default
style_screen4_sw_5_main_knob_default = lv.style_t()
style_screen4_sw_5_main_knob_default.init()
style_screen4_sw_5_main_knob_default.set_radius(100)
style_screen4_sw_5_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_5_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen4_sw_5_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen4_sw_5_main_knob_default.set_bg_opa(255)

# add style for screen4_sw_5
screen4_sw_5.add_style(style_screen4_sw_5_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen5 = lv.obj()
# create style style_screen5_main_main_default
style_screen5_main_main_default = lv.style_t()
style_screen5_main_main_default.init()
style_screen5_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen5_main_main_default.set_bg_opa(0)

# add style for screen5
screen5.add_style(style_screen5_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen5_imgbtn_3 = lv.imgbtn(screen5)
screen5_imgbtn_3.set_pos(6,7)
screen5_imgbtn_3.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen5_imgbtn_3_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen5_imgbtn_3_imgReleased = lv.img_dsc_t({
  'data_size': len(screen5_imgbtn_3_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen5_imgbtn_3_imgReleased_data
})
screen5_imgbtn_3.set_src(lv.imgbtn.STATE.RELEASED, screen5_imgbtn_3_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen5_imgbtn_3_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen5_imgbtn_3_imgPressed = lv.img_dsc_t({
  'data_size': len(screen5_imgbtn_3_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen5_imgbtn_3_imgPressed_data
})
screen5_imgbtn_3.set_src(lv.imgbtn.STATE.PRESSED, screen5_imgbtn_3_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen5_imgbtn_3_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen5_imgbtn_3_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen5_imgbtn_3_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen5_imgbtn_3_imgCheckedReleased_data
})
screen5_imgbtn_3.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen5_imgbtn_3_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen5_imgbtn_3_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen5_imgbtn_3_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen5_imgbtn_3_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen5_imgbtn_3_imgCheckedPressed_data
})
screen5_imgbtn_3.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen5_imgbtn_3_imgCheckedPressed, None, None)

screen5_imgbtn_3.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen5_imgbtn_3_main_main_default
style_screen5_imgbtn_3_main_main_default = lv.style_t()
style_screen5_imgbtn_3_main_main_default.init()
style_screen5_imgbtn_3_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen5_imgbtn_3_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen5_imgbtn_3_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen5_imgbtn_3_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen5_imgbtn_3_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen5_imgbtn_3_main_main_default.set_img_recolor_opa(0)
style_screen5_imgbtn_3_main_main_default.set_img_opa(255)

# add style for screen5_imgbtn_3
screen5_imgbtn_3.add_style(style_screen5_imgbtn_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen5_imgbtn_3_main_main_pressed
style_screen5_imgbtn_3_main_main_pressed = lv.style_t()
style_screen5_imgbtn_3_main_main_pressed.init()
style_screen5_imgbtn_3_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen5_imgbtn_3_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen5_imgbtn_3_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen5_imgbtn_3_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen5_imgbtn_3_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen5_imgbtn_3_main_main_pressed.set_img_recolor_opa(0)

# add style for screen5_imgbtn_3
screen5_imgbtn_3.add_style(style_screen5_imgbtn_3_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen5_imgbtn_3_main_main_checked
style_screen5_imgbtn_3_main_main_checked = lv.style_t()
style_screen5_imgbtn_3_main_main_checked.init()
style_screen5_imgbtn_3_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen5_imgbtn_3_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen5_imgbtn_3_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen5_imgbtn_3_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen5_imgbtn_3_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen5_imgbtn_3_main_main_checked.set_img_recolor_opa(0)

# add style for screen5_imgbtn_3
screen5_imgbtn_3.add_style(style_screen5_imgbtn_3_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen5_img_1 = lv.img(screen5)
screen5_img_1.set_pos(34,46)
screen5_img_1.set_size(242,159)
screen5_img_1.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1684846386.png','rb') as f:
        screen5_img_1_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1684846386.png')
    sys.exit()

screen5_img_1_img = lv.img_dsc_t({
  'data_size': len(screen5_img_1_img_data),
  'header': {'always_zero': 0, 'w': 242, 'h': 159, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen5_img_1_img_data
})

screen5_img_1.set_src(screen5_img_1_img)
screen5_img_1.set_pivot(0,0)
screen5_img_1.set_angle(0)
# create style style_screen5_img_1_main_main_default
style_screen5_img_1_main_main_default = lv.style_t()
style_screen5_img_1_main_main_default.init()
style_screen5_img_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen5_img_1_main_main_default.set_img_recolor_opa(0)
style_screen5_img_1_main_main_default.set_img_opa(255)

# add style for screen5_img_1
screen5_img_1.add_style(style_screen5_img_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6 = lv.obj()
# create style style_screen6_main_main_default
style_screen6_main_main_default = lv.style_t()
style_screen6_main_main_default.init()
style_screen6_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen6_main_main_default.set_bg_opa(0)

# add style for screen6
screen6.add_style(style_screen6_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_imgbtn_4 = lv.imgbtn(screen6)
screen6_imgbtn_4.set_pos(6,4)
screen6_imgbtn_4.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen6_imgbtn_4_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen6_imgbtn_4_imgReleased = lv.img_dsc_t({
  'data_size': len(screen6_imgbtn_4_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen6_imgbtn_4_imgReleased_data
})
screen6_imgbtn_4.set_src(lv.imgbtn.STATE.RELEASED, screen6_imgbtn_4_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen6_imgbtn_4_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen6_imgbtn_4_imgPressed = lv.img_dsc_t({
  'data_size': len(screen6_imgbtn_4_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen6_imgbtn_4_imgPressed_data
})
screen6_imgbtn_4.set_src(lv.imgbtn.STATE.PRESSED, screen6_imgbtn_4_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen6_imgbtn_4_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen6_imgbtn_4_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen6_imgbtn_4_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen6_imgbtn_4_imgCheckedReleased_data
})
screen6_imgbtn_4.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen6_imgbtn_4_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen6_imgbtn_4_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen6_imgbtn_4_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen6_imgbtn_4_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen6_imgbtn_4_imgCheckedPressed_data
})
screen6_imgbtn_4.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen6_imgbtn_4_imgCheckedPressed, None, None)

screen6_imgbtn_4.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen6_imgbtn_4_main_main_default
style_screen6_imgbtn_4_main_main_default = lv.style_t()
style_screen6_imgbtn_4_main_main_default.init()
style_screen6_imgbtn_4_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen6_imgbtn_4_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen6_imgbtn_4_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen6_imgbtn_4_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen6_imgbtn_4_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen6_imgbtn_4_main_main_default.set_img_recolor_opa(0)
style_screen6_imgbtn_4_main_main_default.set_img_opa(255)

# add style for screen6_imgbtn_4
screen6_imgbtn_4.add_style(style_screen6_imgbtn_4_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen6_imgbtn_4_main_main_pressed
style_screen6_imgbtn_4_main_main_pressed = lv.style_t()
style_screen6_imgbtn_4_main_main_pressed.init()
style_screen6_imgbtn_4_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen6_imgbtn_4_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen6_imgbtn_4_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen6_imgbtn_4_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen6_imgbtn_4_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen6_imgbtn_4_main_main_pressed.set_img_recolor_opa(0)

# add style for screen6_imgbtn_4
screen6_imgbtn_4.add_style(style_screen6_imgbtn_4_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen6_imgbtn_4_main_main_checked
style_screen6_imgbtn_4_main_main_checked = lv.style_t()
style_screen6_imgbtn_4_main_main_checked.init()
style_screen6_imgbtn_4_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen6_imgbtn_4_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen6_imgbtn_4_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen6_imgbtn_4_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen6_imgbtn_4_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen6_imgbtn_4_main_main_checked.set_img_recolor_opa(0)

# add style for screen6_imgbtn_4
screen6_imgbtn_4.add_style(style_screen6_imgbtn_4_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen6_label_16 = lv.label(screen6)
screen6_label_16.set_pos(14,79)
screen6_label_16.set_size(120,31)
screen6_label_16.set_text("自助查药")
screen6_label_16.set_long_mode(lv.label.LONG.WRAP)
screen6_label_16.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen6_label_16_main_main_default
style_screen6_label_16_main_main_default = lv.style_t()
style_screen6_label_16_main_main_default.init()
style_screen6_label_16_main_main_default.set_radius(10)
style_screen6_label_16_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen6_label_16_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen6_label_16_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_label_16_main_main_default.set_bg_opa(255)
style_screen6_label_16_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen6_label_16_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen6_label_16_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen6_label_16_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen6_label_16_main_main_default.set_text_letter_space(2)
style_screen6_label_16_main_main_default.set_pad_left(0)
style_screen6_label_16_main_main_default.set_pad_right(0)
style_screen6_label_16_main_main_default.set_pad_top(0)
style_screen6_label_16_main_main_default.set_pad_bottom(0)

# add style for screen6_label_16
screen6_label_16.add_style(style_screen6_label_16_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_label_17 = lv.label(screen6)
screen6_label_17.set_pos(170,80)
screen6_label_17.set_size(120,31)
screen6_label_17.set_text("紧急呼叫")
screen6_label_17.set_long_mode(lv.label.LONG.WRAP)
screen6_label_17.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen6_label_17_main_main_default
style_screen6_label_17_main_main_default = lv.style_t()
style_screen6_label_17_main_main_default.init()
style_screen6_label_17_main_main_default.set_radius(10)
style_screen6_label_17_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen6_label_17_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen6_label_17_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_label_17_main_main_default.set_bg_opa(255)
style_screen6_label_17_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen6_label_17_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen6_label_17_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen6_label_17_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen6_label_17_main_main_default.set_text_letter_space(2)
style_screen6_label_17_main_main_default.set_pad_left(0)
style_screen6_label_17_main_main_default.set_pad_right(0)
style_screen6_label_17_main_main_default.set_pad_top(0)
style_screen6_label_17_main_main_default.set_pad_bottom(0)

# add style for screen6_label_17
screen6_label_17.add_style(style_screen6_label_17_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_sw_6 = lv.switch(screen6)
screen6_sw_6.set_pos(53,88)
screen6_sw_6.set_size(35,18)
# create style style_screen6_sw_6_main_main_default
style_screen6_sw_6_main_main_default = lv.style_t()
style_screen6_sw_6_main_main_default.init()
style_screen6_sw_6_main_main_default.set_radius(100)
style_screen6_sw_6_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen6_sw_6_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen6_sw_6_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_sw_6_main_main_default.set_bg_opa(255)

# add style for screen6_sw_6
screen6_sw_6.add_style(style_screen6_sw_6_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen6_sw_6_main_indicator_checked
style_screen6_sw_6_main_indicator_checked = lv.style_t()
style_screen6_sw_6_main_indicator_checked.init()
style_screen6_sw_6_main_indicator_checked.set_radius(100)
style_screen6_sw_6_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_sw_6_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_sw_6_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_sw_6_main_indicator_checked.set_bg_opa(255)

# add style for screen6_sw_6
screen6_sw_6.add_style(style_screen6_sw_6_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen6_sw_6_main_knob_default
style_screen6_sw_6_main_knob_default = lv.style_t()
style_screen6_sw_6_main_knob_default.init()
style_screen6_sw_6_main_knob_default.set_radius(100)
style_screen6_sw_6_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen6_sw_6_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen6_sw_6_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_sw_6_main_knob_default.set_bg_opa(255)

# add style for screen6_sw_6
screen6_sw_6.add_style(style_screen6_sw_6_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen6_sw_7 = lv.switch(screen6)
screen6_sw_7.set_pos(214,92)
screen6_sw_7.set_size(35,18)
# create style style_screen6_sw_7_main_main_default
style_screen6_sw_7_main_main_default = lv.style_t()
style_screen6_sw_7_main_main_default.init()
style_screen6_sw_7_main_main_default.set_radius(100)
style_screen6_sw_7_main_main_default.set_bg_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen6_sw_7_main_main_default.set_bg_grad_color(lv.color_make(0xe6,0xe2,0xe6))
style_screen6_sw_7_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_sw_7_main_main_default.set_bg_opa(255)

# add style for screen6_sw_7
screen6_sw_7.add_style(style_screen6_sw_7_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen6_sw_7_main_indicator_checked
style_screen6_sw_7_main_indicator_checked = lv.style_t()
style_screen6_sw_7_main_indicator_checked.init()
style_screen6_sw_7_main_indicator_checked.set_radius(100)
style_screen6_sw_7_main_indicator_checked.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_sw_7_main_indicator_checked.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_sw_7_main_indicator_checked.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_sw_7_main_indicator_checked.set_bg_opa(255)

# add style for screen6_sw_7
screen6_sw_7.add_style(style_screen6_sw_7_main_indicator_checked, lv.PART.INDICATOR|lv.STATE.CHECKED)

# create style style_screen6_sw_7_main_knob_default
style_screen6_sw_7_main_knob_default = lv.style_t()
style_screen6_sw_7_main_knob_default.init()
style_screen6_sw_7_main_knob_default.set_radius(100)
style_screen6_sw_7_main_knob_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen6_sw_7_main_knob_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen6_sw_7_main_knob_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_sw_7_main_knob_default.set_bg_opa(255)

# add style for screen6_sw_7
screen6_sw_7.add_style(style_screen6_sw_7_main_knob_default, lv.PART.KNOB|lv.STATE.DEFAULT)

screen6_label_18 = lv.label(screen6)
screen6_label_18.set_pos(6,151)
screen6_label_18.set_size(300,16)
screen6_label_18.set_text("如需其他帮助可通过下面方式联系我们")
screen6_label_18.set_long_mode(lv.label.LONG.WRAP)
screen6_label_18.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen6_label_18_main_main_default
style_screen6_label_18_main_main_default = lv.style_t()
style_screen6_label_18_main_main_default.init()
style_screen6_label_18_main_main_default.set_radius(0)
style_screen6_label_18_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_label_18_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_label_18_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_label_18_main_main_default.set_bg_opa(0)
style_screen6_label_18_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen6_label_18_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen6_label_18_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen6_label_18_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen6_label_18_main_main_default.set_text_letter_space(2)
style_screen6_label_18_main_main_default.set_pad_left(0)
style_screen6_label_18_main_main_default.set_pad_right(0)
style_screen6_label_18_main_main_default.set_pad_top(0)
style_screen6_label_18_main_main_default.set_pad_bottom(0)

# add style for screen6_label_18
screen6_label_18.add_style(style_screen6_label_18_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_label_19 = lv.label(screen6)
screen6_label_19.set_pos(32,176)
screen6_label_19.set_size(100,32)
screen6_label_19.set_text("电话：123456")
screen6_label_19.set_long_mode(lv.label.LONG.WRAP)
screen6_label_19.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen6_label_19_main_main_default
style_screen6_label_19_main_main_default = lv.style_t()
style_screen6_label_19_main_main_default.init()
style_screen6_label_19_main_main_default.set_radius(0)
style_screen6_label_19_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_label_19_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_label_19_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_label_19_main_main_default.set_bg_opa(0)
style_screen6_label_19_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen6_label_19_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen6_label_19_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen6_label_19_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen6_label_19_main_main_default.set_text_letter_space(2)
style_screen6_label_19_main_main_default.set_pad_left(0)
style_screen6_label_19_main_main_default.set_pad_right(0)
style_screen6_label_19_main_main_default.set_pad_top(0)
style_screen6_label_19_main_main_default.set_pad_bottom(0)

# add style for screen6_label_19
screen6_label_19.add_style(style_screen6_label_19_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_img_1 = lv.img(screen6)
screen6_img_1.set_pos(20,79)
screen6_img_1.set_size(24,24)
screen6_img_1.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp35628124.png','rb') as f:
        screen6_img_1_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp35628124.png')
    sys.exit()

screen6_img_1_img = lv.img_dsc_t({
  'data_size': len(screen6_img_1_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen6_img_1_img_data
})

screen6_img_1.set_src(screen6_img_1_img)
screen6_img_1.set_pivot(0,0)
screen6_img_1.set_angle(0)
# create style style_screen6_img_1_main_main_default
style_screen6_img_1_main_main_default = lv.style_t()
style_screen6_img_1_main_main_default.init()
style_screen6_img_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen6_img_1_main_main_default.set_img_recolor_opa(0)
style_screen6_img_1_main_main_default.set_img_opa(255)

# add style for screen6_img_1
screen6_img_1.add_style(style_screen6_img_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_img_2 = lv.img(screen6)
screen6_img_2.set_pos(175,84)
screen6_img_2.set_size(24,24)
screen6_img_2.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1082310934.png','rb') as f:
        screen6_img_2_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1082310934.png')
    sys.exit()

screen6_img_2_img = lv.img_dsc_t({
  'data_size': len(screen6_img_2_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen6_img_2_img_data
})

screen6_img_2.set_src(screen6_img_2_img)
screen6_img_2.set_pivot(0,0)
screen6_img_2.set_angle(0)
# create style style_screen6_img_2_main_main_default
style_screen6_img_2_main_main_default = lv.style_t()
style_screen6_img_2_main_main_default.init()
style_screen6_img_2_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen6_img_2_main_main_default.set_img_recolor_opa(0)
style_screen6_img_2_main_main_default.set_img_opa(255)

# add style for screen6_img_2
screen6_img_2.add_style(style_screen6_img_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen6_label_20 = lv.label(screen6)
screen6_label_20.set_pos(100,18)
screen6_label_20.set_size(100,32)
screen6_label_20.set_text("HELP")
screen6_label_20.set_long_mode(lv.label.LONG.WRAP)
screen6_label_20.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen6_label_20_main_main_default
style_screen6_label_20_main_main_default = lv.style_t()
style_screen6_label_20_main_main_default.init()
style_screen6_label_20_main_main_default.set_radius(0)
style_screen6_label_20_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_label_20_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen6_label_20_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen6_label_20_main_main_default.set_bg_opa(0)
style_screen6_label_20_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen6_label_20_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen6_label_20_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen6_label_20_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen6_label_20_main_main_default.set_text_letter_space(2)
style_screen6_label_20_main_main_default.set_pad_left(0)
style_screen6_label_20_main_main_default.set_pad_right(0)
style_screen6_label_20_main_main_default.set_pad_top(0)
style_screen6_label_20_main_main_default.set_pad_bottom(0)

# add style for screen6_label_20
screen6_label_20.add_style(style_screen6_label_20_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen7 = lv.obj()
# create style style_screen7_main_main_default
style_screen7_main_main_default = lv.style_t()
style_screen7_main_main_default.init()
style_screen7_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen7_main_main_default.set_bg_opa(0)

# add style for screen7
screen7.add_style(style_screen7_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen7_imgbtn_5 = lv.imgbtn(screen7)
screen7_imgbtn_5.set_pos(5,6)
screen7_imgbtn_5.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen7_imgbtn_5_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen7_imgbtn_5_imgReleased = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_5_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_5_imgReleased_data
})
screen7_imgbtn_5.set_src(lv.imgbtn.STATE.RELEASED, screen7_imgbtn_5_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen7_imgbtn_5_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen7_imgbtn_5_imgPressed = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_5_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_5_imgPressed_data
})
screen7_imgbtn_5.set_src(lv.imgbtn.STATE.PRESSED, screen7_imgbtn_5_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen7_imgbtn_5_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen7_imgbtn_5_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_5_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_5_imgCheckedReleased_data
})
screen7_imgbtn_5.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen7_imgbtn_5_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen7_imgbtn_5_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen7_imgbtn_5_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_5_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_5_imgCheckedPressed_data
})
screen7_imgbtn_5.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen7_imgbtn_5_imgCheckedPressed, None, None)

screen7_imgbtn_5.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen7_imgbtn_5_main_main_default
style_screen7_imgbtn_5_main_main_default = lv.style_t()
style_screen7_imgbtn_5_main_main_default.init()
style_screen7_imgbtn_5_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen7_imgbtn_5_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen7_imgbtn_5_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen7_imgbtn_5_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_5_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen7_imgbtn_5_main_main_default.set_img_recolor_opa(0)
style_screen7_imgbtn_5_main_main_default.set_img_opa(255)

# add style for screen7_imgbtn_5
screen7_imgbtn_5.add_style(style_screen7_imgbtn_5_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen7_imgbtn_5_main_main_pressed
style_screen7_imgbtn_5_main_main_pressed = lv.style_t()
style_screen7_imgbtn_5_main_main_pressed.init()
style_screen7_imgbtn_5_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen7_imgbtn_5_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen7_imgbtn_5_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_imgbtn_5_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_5_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen7_imgbtn_5_main_main_pressed.set_img_recolor_opa(0)

# add style for screen7_imgbtn_5
screen7_imgbtn_5.add_style(style_screen7_imgbtn_5_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen7_imgbtn_5_main_main_checked
style_screen7_imgbtn_5_main_main_checked = lv.style_t()
style_screen7_imgbtn_5_main_main_checked.init()
style_screen7_imgbtn_5_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen7_imgbtn_5_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen7_imgbtn_5_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_imgbtn_5_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_5_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen7_imgbtn_5_main_main_checked.set_img_recolor_opa(0)

# add style for screen7_imgbtn_5
screen7_imgbtn_5.add_style(style_screen7_imgbtn_5_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen7_cb_1 = lv.checkbox(screen7)
screen7_cb_1.set_pos(37,68)
screen7_cb_1.set_text("doctor")
# create style style_screen7_cb_1_main_main_default
style_screen7_cb_1_main_main_default = lv.style_t()
style_screen7_cb_1_main_main_default.init()
style_screen7_cb_1_main_main_default.set_radius(6)
style_screen7_cb_1_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_1_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen7_cb_1_main_main_default.set_bg_opa(0)
style_screen7_cb_1_main_main_default.set_text_color(lv.color_make(0x0D,0x30,0x55))
try:
    style_screen7_cb_1_main_main_default.set_text_font(lv.font_arial_16)
except AttributeError:
    try:
        style_screen7_cb_1_main_main_default.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_cb_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_cb_1_main_main_default.set_text_letter_space(0)

# add style for screen7_cb_1
screen7_cb_1.add_style(style_screen7_cb_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen7_cb_1_main_indicator_default
style_screen7_cb_1_main_indicator_default = lv.style_t()
style_screen7_cb_1_main_indicator_default.init()
style_screen7_cb_1_main_indicator_default.set_radius(6)
style_screen7_cb_1_main_indicator_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_1_main_indicator_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_1_main_indicator_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen7_cb_1_main_indicator_default.set_bg_opa(255)
style_screen7_cb_1_main_indicator_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen7_cb_1_main_indicator_default.set_border_width(2)

# add style for screen7_cb_1
screen7_cb_1.add_style(style_screen7_cb_1_main_indicator_default, lv.PART.INDICATOR|lv.STATE.DEFAULT)

screen7_cb_2 = lv.checkbox(screen7)
screen7_cb_2.set_pos(200,69)
screen7_cb_2.set_text("patient")
# create style style_screen7_cb_2_main_main_default
style_screen7_cb_2_main_main_default = lv.style_t()
style_screen7_cb_2_main_main_default.init()
style_screen7_cb_2_main_main_default.set_radius(6)
style_screen7_cb_2_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_2_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_2_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.NONE)
style_screen7_cb_2_main_main_default.set_bg_opa(0)
style_screen7_cb_2_main_main_default.set_text_color(lv.color_make(0x0D,0x30,0x55))
try:
    style_screen7_cb_2_main_main_default.set_text_font(lv.font_arial_16)
except AttributeError:
    try:
        style_screen7_cb_2_main_main_default.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_cb_2_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_cb_2_main_main_default.set_text_letter_space(0)

# add style for screen7_cb_2
screen7_cb_2.add_style(style_screen7_cb_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen7_cb_2_main_indicator_default
style_screen7_cb_2_main_indicator_default = lv.style_t()
style_screen7_cb_2_main_indicator_default.init()
style_screen7_cb_2_main_indicator_default.set_radius(6)
style_screen7_cb_2_main_indicator_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_2_main_indicator_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen7_cb_2_main_indicator_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen7_cb_2_main_indicator_default.set_bg_opa(255)
style_screen7_cb_2_main_indicator_default.set_border_color(lv.color_make(0x21,0x95,0xf6))
style_screen7_cb_2_main_indicator_default.set_border_width(2)

# add style for screen7_cb_2
screen7_cb_2.add_style(style_screen7_cb_2_main_indicator_default, lv.PART.INDICATOR|lv.STATE.DEFAULT)

screen7_label_16 = lv.label(screen7)
screen7_label_16.set_pos(100,14)
screen7_label_16.set_size(120,31)
screen7_label_16.set_text("change")
screen7_label_16.set_long_mode(lv.label.LONG.WRAP)
screen7_label_16.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen7_label_16_main_main_default
style_screen7_label_16_main_main_default = lv.style_t()
style_screen7_label_16_main_main_default.init()
style_screen7_label_16_main_main_default.set_radius(10)
style_screen7_label_16_main_main_default.set_bg_color(lv.color_make(0xf0,0xf0,0xff))
style_screen7_label_16_main_main_default.set_bg_grad_color(lv.color_make(0xf1,0xf0,0xff))
style_screen7_label_16_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen7_label_16_main_main_default.set_bg_opa(0)
style_screen7_label_16_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen7_label_16_main_main_default.set_text_font(lv.font_arial_20)
except AttributeError:
    try:
        style_screen7_label_16_main_main_default.set_text_font(lv.font_montserrat_20)
    except AttributeError:
        style_screen7_label_16_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_label_16_main_main_default.set_text_letter_space(2)
style_screen7_label_16_main_main_default.set_pad_left(0)
style_screen7_label_16_main_main_default.set_pad_right(0)
style_screen7_label_16_main_main_default.set_pad_top(0)
style_screen7_label_16_main_main_default.set_pad_bottom(0)

# add style for screen7_label_16
screen7_label_16.add_style(style_screen7_label_16_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen7_label_17 = lv.label(screen7)
screen7_label_17.set_pos(81,194)
screen7_label_17.set_size(140,32)
screen7_label_17.set_text("tip")
screen7_label_17.set_long_mode(lv.label.LONG.WRAP)
screen7_label_17.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen7_label_17_main_main_default
style_screen7_label_17_main_main_default = lv.style_t()
style_screen7_label_17_main_main_default.init()
style_screen7_label_17_main_main_default.set_radius(0)
style_screen7_label_17_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen7_label_17_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen7_label_17_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen7_label_17_main_main_default.set_bg_opa(0)
style_screen7_label_17_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen7_label_17_main_main_default.set_text_font(lv.font_arial_12)
except AttributeError:
    try:
        style_screen7_label_17_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen7_label_17_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_label_17_main_main_default.set_text_letter_space(2)
style_screen7_label_17_main_main_default.set_pad_left(0)
style_screen7_label_17_main_main_default.set_pad_right(0)
style_screen7_label_17_main_main_default.set_pad_top(0)
style_screen7_label_17_main_main_default.set_pad_bottom(0)

# add style for screen7_label_17
screen7_label_17.add_style(style_screen7_label_17_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen7_imgbtn_6 = lv.imgbtn(screen7)
screen7_imgbtn_6.set_pos(37,113)
screen7_imgbtn_6.set_size(70,70)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2104747026.png','rb') as f:
        screen7_imgbtn_6_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2104747026.png')
    sys.exit()

screen7_imgbtn_6_imgReleased = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_6_imgReleased_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_6_imgReleased_data
})
screen7_imgbtn_6.set_src(lv.imgbtn.STATE.RELEASED, screen7_imgbtn_6_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1049183309.png','rb') as f:
        screen7_imgbtn_6_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1049183309.png')
    sys.exit()

screen7_imgbtn_6_imgPressed = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_6_imgPressed_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_6_imgPressed_data
})
screen7_imgbtn_6.set_src(lv.imgbtn.STATE.PRESSED, screen7_imgbtn_6_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2104747026.png','rb') as f:
        screen7_imgbtn_6_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2104747026.png')
    sys.exit()

screen7_imgbtn_6_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_6_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_6_imgCheckedReleased_data
})
screen7_imgbtn_6.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen7_imgbtn_6_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2104747026.png','rb') as f:
        screen7_imgbtn_6_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2104747026.png')
    sys.exit()

screen7_imgbtn_6_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_6_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_6_imgCheckedPressed_data
})
screen7_imgbtn_6.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen7_imgbtn_6_imgCheckedPressed, None, None)

screen7_imgbtn_6.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen7_imgbtn_6_main_main_default
style_screen7_imgbtn_6_main_main_default = lv.style_t()
style_screen7_imgbtn_6_main_main_default.init()
style_screen7_imgbtn_6_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen7_imgbtn_6_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen7_imgbtn_6_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen7_imgbtn_6_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_6_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen7_imgbtn_6_main_main_default.set_img_recolor_opa(0)
style_screen7_imgbtn_6_main_main_default.set_img_opa(255)

# add style for screen7_imgbtn_6
screen7_imgbtn_6.add_style(style_screen7_imgbtn_6_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen7_imgbtn_6_main_main_pressed
style_screen7_imgbtn_6_main_main_pressed = lv.style_t()
style_screen7_imgbtn_6_main_main_pressed.init()
style_screen7_imgbtn_6_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen7_imgbtn_6_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen7_imgbtn_6_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_imgbtn_6_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_6_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen7_imgbtn_6_main_main_pressed.set_img_recolor_opa(0)

# add style for screen7_imgbtn_6
screen7_imgbtn_6.add_style(style_screen7_imgbtn_6_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen7_imgbtn_6_main_main_checked
style_screen7_imgbtn_6_main_main_checked = lv.style_t()
style_screen7_imgbtn_6_main_main_checked.init()
style_screen7_imgbtn_6_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen7_imgbtn_6_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen7_imgbtn_6_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_imgbtn_6_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_6_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen7_imgbtn_6_main_main_checked.set_img_recolor_opa(0)

# add style for screen7_imgbtn_6
screen7_imgbtn_6.add_style(style_screen7_imgbtn_6_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen7_imgbtn_7 = lv.imgbtn(screen7)
screen7_imgbtn_7.set_pos(200,112)
screen7_imgbtn_7.set_size(70,70)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1357641999.png','rb') as f:
        screen7_imgbtn_7_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1357641999.png')
    sys.exit()

screen7_imgbtn_7_imgReleased = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_7_imgReleased_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_7_imgReleased_data
})
screen7_imgbtn_7.set_src(lv.imgbtn.STATE.RELEASED, screen7_imgbtn_7_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1213806766.png','rb') as f:
        screen7_imgbtn_7_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1213806766.png')
    sys.exit()

screen7_imgbtn_7_imgPressed = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_7_imgPressed_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_7_imgPressed_data
})
screen7_imgbtn_7.set_src(lv.imgbtn.STATE.PRESSED, screen7_imgbtn_7_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1357641999.png','rb') as f:
        screen7_imgbtn_7_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1357641999.png')
    sys.exit()

screen7_imgbtn_7_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_7_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_7_imgCheckedReleased_data
})
screen7_imgbtn_7.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen7_imgbtn_7_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1213806766.png','rb') as f:
        screen7_imgbtn_7_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-1213806766.png')
    sys.exit()

screen7_imgbtn_7_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen7_imgbtn_7_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 70, 'h': 70, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen7_imgbtn_7_imgCheckedPressed_data
})
screen7_imgbtn_7.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen7_imgbtn_7_imgCheckedPressed, None, None)

screen7_imgbtn_7.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen7_imgbtn_7_main_main_default
style_screen7_imgbtn_7_main_main_default = lv.style_t()
style_screen7_imgbtn_7_main_main_default.init()
style_screen7_imgbtn_7_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen7_imgbtn_7_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen7_imgbtn_7_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen7_imgbtn_7_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_7_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen7_imgbtn_7_main_main_default.set_img_recolor_opa(0)
style_screen7_imgbtn_7_main_main_default.set_img_opa(255)

# add style for screen7_imgbtn_7
screen7_imgbtn_7.add_style(style_screen7_imgbtn_7_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen7_imgbtn_7_main_main_pressed
style_screen7_imgbtn_7_main_main_pressed = lv.style_t()
style_screen7_imgbtn_7_main_main_pressed.init()
style_screen7_imgbtn_7_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen7_imgbtn_7_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen7_imgbtn_7_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_imgbtn_7_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_7_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen7_imgbtn_7_main_main_pressed.set_img_recolor_opa(0)

# add style for screen7_imgbtn_7
screen7_imgbtn_7.add_style(style_screen7_imgbtn_7_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen7_imgbtn_7_main_main_checked
style_screen7_imgbtn_7_main_main_checked = lv.style_t()
style_screen7_imgbtn_7_main_main_checked.init()
style_screen7_imgbtn_7_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen7_imgbtn_7_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen7_imgbtn_7_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen7_imgbtn_7_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen7_imgbtn_7_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen7_imgbtn_7_main_main_checked.set_img_recolor_opa(0)

# add style for screen7_imgbtn_7
screen7_imgbtn_7.add_style(style_screen7_imgbtn_7_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen8 = lv.obj()
# create style style_screen8_main_main_default
style_screen8_main_main_default = lv.style_t()
style_screen8_main_main_default.init()
style_screen8_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen8_main_main_default.set_bg_opa(0)

# add style for screen8
screen8.add_style(style_screen8_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen8_tileview_1 = lv.tileview(screen8)
screen8_tileview_1.set_pos(0,0)
screen8_tileview_1.set_size(320,240)
screen8_tileview_1_tileview = screen8_tileview_1.add_tile(0, 0, lv.DIR.BOTTOM)
screen8_imgbtn_1 = lv.imgbtn(screen8_tileview_1_tileview)
screen8_imgbtn_1.set_pos(5,4)
screen8_imgbtn_1.set_size(32,27)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen8_imgbtn_1_imgReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen8_imgbtn_1_imgReleased = lv.img_dsc_t({
  'data_size': len(screen8_imgbtn_1_imgReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen8_imgbtn_1_imgReleased_data
})
screen8_imgbtn_1.set_src(lv.imgbtn.STATE.RELEASED, screen8_imgbtn_1_imgReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png','rb') as f:
        screen8_imgbtn_1_imgPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp1558913715.png')
    sys.exit()

screen8_imgbtn_1_imgPressed = lv.img_dsc_t({
  'data_size': len(screen8_imgbtn_1_imgPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen8_imgbtn_1_imgPressed_data
})
screen8_imgbtn_1.set_src(lv.imgbtn.STATE.PRESSED, screen8_imgbtn_1_imgPressed, None, None)


try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen8_imgbtn_1_imgCheckedReleased_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen8_imgbtn_1_imgCheckedReleased = lv.img_dsc_t({
  'data_size': len(screen8_imgbtn_1_imgCheckedReleased_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen8_imgbtn_1_imgCheckedReleased_data
})
screen8_imgbtn_1.set_src(lv.imgbtn.STATE.CHECKED_RELEASED, screen8_imgbtn_1_imgCheckedReleased, None, None)

try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png','rb') as f:
        screen8_imgbtn_1_imgCheckedPressed_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp2086976716.png')
    sys.exit()

screen8_imgbtn_1_imgCheckedPressed = lv.img_dsc_t({
  'data_size': len(screen8_imgbtn_1_imgCheckedPressed_data),
  'header': {'always_zero': 0, 'w': 32, 'h': 27, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen8_imgbtn_1_imgCheckedPressed_data
})
screen8_imgbtn_1.set_src(lv.imgbtn.STATE.CHECKED_PRESSED, screen8_imgbtn_1_imgCheckedPressed, None, None)

screen8_imgbtn_1.add_flag(lv.obj.FLAG.CHECKABLE)
# create style style_screen8_imgbtn_1_main_main_default
style_screen8_imgbtn_1_main_main_default = lv.style_t()
style_screen8_imgbtn_1_main_main_default.init()
style_screen8_imgbtn_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen8_imgbtn_1_main_main_default.set_text_font(lv.font_simsun_12)
except AttributeError:
    try:
        style_screen8_imgbtn_1_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen8_imgbtn_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen8_imgbtn_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen8_imgbtn_1_main_main_default.set_img_recolor_opa(0)
style_screen8_imgbtn_1_main_main_default.set_img_opa(255)

# add style for screen8_imgbtn_1
screen8_imgbtn_1.add_style(style_screen8_imgbtn_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_imgbtn_1_main_main_pressed
style_screen8_imgbtn_1_main_main_pressed = lv.style_t()
style_screen8_imgbtn_1_main_main_pressed.init()
style_screen8_imgbtn_1_main_main_pressed.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen8_imgbtn_1_main_main_pressed.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen8_imgbtn_1_main_main_pressed.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen8_imgbtn_1_main_main_pressed.set_text_font(lv.font_montserrat_16)
style_screen8_imgbtn_1_main_main_pressed.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen8_imgbtn_1_main_main_pressed.set_img_recolor_opa(0)

# add style for screen8_imgbtn_1
screen8_imgbtn_1.add_style(style_screen8_imgbtn_1_main_main_pressed, lv.PART.MAIN|lv.STATE.PRESSED)

# create style style_screen8_imgbtn_1_main_main_checked
style_screen8_imgbtn_1_main_main_checked = lv.style_t()
style_screen8_imgbtn_1_main_main_checked.init()
style_screen8_imgbtn_1_main_main_checked.set_text_color(lv.color_make(0xFF,0x33,0xFF))
try:
    style_screen8_imgbtn_1_main_main_checked.set_text_font(lv.font_simsun_16)
except AttributeError:
    try:
        style_screen8_imgbtn_1_main_main_checked.set_text_font(lv.font_montserrat_16)
    except AttributeError:
        style_screen8_imgbtn_1_main_main_checked.set_text_font(lv.font_montserrat_16)
style_screen8_imgbtn_1_main_main_checked.set_img_recolor(lv.color_make(0x00,0x00,0x00))
style_screen8_imgbtn_1_main_main_checked.set_img_recolor_opa(0)

# add style for screen8_imgbtn_1
screen8_imgbtn_1.add_style(style_screen8_imgbtn_1_main_main_checked, lv.PART.MAIN|lv.STATE.CHECKED)

screen8_img_1 = lv.img(screen8_tileview_1_tileview)
screen8_img_1.set_pos(111,21)
screen8_img_1.set_size(24,24)
screen8_img_1.add_flag(lv.obj.FLAG.CLICKABLE)
try:
    with open('C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-928932038.png','rb') as f:
        screen8_img_1_img_data = f.read()
except:
    print('Could not open C:\\NXP\\GUI-Guider-Projects\\AIF4GUI\\generated\\mPythonImages\\mp-928932038.png')
    sys.exit()

screen8_img_1_img = lv.img_dsc_t({
  'data_size': len(screen8_img_1_img_data),
  'header': {'always_zero': 0, 'w': 24, 'h': 24, 'cf': lv.img.CF.TRUE_COLOR_ALPHA},
  'data': screen8_img_1_img_data
})

screen8_img_1.set_src(screen8_img_1_img)
screen8_img_1.set_pivot(0,0)
screen8_img_1.set_angle(0)
# create style style_screen8_img_1_main_main_default
style_screen8_img_1_main_main_default = lv.style_t()
style_screen8_img_1_main_main_default.init()
style_screen8_img_1_main_main_default.set_img_recolor(lv.color_make(0xff,0xff,0xff))
style_screen8_img_1_main_main_default.set_img_recolor_opa(0)
style_screen8_img_1_main_main_default.set_img_opa(255)

# add style for screen8_img_1
screen8_img_1.add_style(style_screen8_img_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen8_label_1 = lv.label(screen8_tileview_1_tileview)
screen8_label_1.set_pos(104,24)
screen8_label_1.set_size(120,31)
screen8_label_1.set_text("12:00")
screen8_label_1.set_long_mode(lv.label.LONG.WRAP)
screen8_label_1.set_style_text_align(lv.TEXT_ALIGN.CENTER, 0)
# create style style_screen8_label_1_main_main_default
style_screen8_label_1_main_main_default = lv.style_t()
style_screen8_label_1_main_main_default.init()
style_screen8_label_1_main_main_default.set_radius(0)
style_screen8_label_1_main_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_label_1_main_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_label_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_label_1_main_main_default.set_bg_opa(0)
style_screen8_label_1_main_main_default.set_text_color(lv.color_make(0x00,0x00,0x00))
try:
    style_screen8_label_1_main_main_default.set_text_font(lv.font_arial_12)
except AttributeError:
    try:
        style_screen8_label_1_main_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen8_label_1_main_main_default.set_text_font(lv.font_montserrat_16)
style_screen8_label_1_main_main_default.set_text_letter_space(2)
style_screen8_label_1_main_main_default.set_pad_left(0)
style_screen8_label_1_main_main_default.set_pad_right(0)
style_screen8_label_1_main_main_default.set_pad_top(0)
style_screen8_label_1_main_main_default.set_pad_bottom(0)

# add style for screen8_label_1
screen8_label_1.add_style(style_screen8_label_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

screen8_roller_1 = lv.roller(screen8_tileview_1_tileview)
screen8_roller_1.set_pos(55,78)
screen8_roller_1.set_options("0\n1\n2\n3\n4\n5\n6\n7\n8\n9\n10\n11\n12\n13\n14\n15\n16\n17\n18\n19\n20\n21\n22\n23\n24", lv.roller.MODE.INFINITE)
screen8_roller_1.set_visible_row_count(3)
try:
	screen8_roller_1.set_style_text_font(lv.font_arial_12, lv.PART.MAIN|lv.STATE.DEFAULT)
	screen8_roller_1.set_style_text_font(lv.font_arial_12, lv.PART.MAIN|lv.STATE.FOCUSED)
	screen8_roller_1.set_style_text_font(lv.font_arial_12, lv.PART.SELECTED|lv.STATE.DEFAULT)
except AttributeError:
	try:
		screen8_roller_1.set_style_text_font(lv.font_montserrat_12, lv.PART.MAIN|lv.STATE.DEFAULT)
		screen8_roller_1.set_style_text_font(lv.font_montserrat_12, lv.PART.MAIN|lv.STATE.FOCUSED)
		screen8_roller_1.set_style_text_font(lv.font_montserrat_12, lv.PART.SELECTED|lv.STATE.DEFAULT)
	except AttributeError:
		screen8_roller_1.set_style_text_font(lv.font_montserrat_16, lv.PART.MAIN|lv.STATE.DEFAULT)
		screen8_roller_1.set_style_text_font(lv.font_montserrat_16, lv.PART.MAIN|lv.STATE.FOCUSED)
		screen8_roller_1.set_style_text_font(lv.font_montserrat_16, lv.PART.SELECTED|lv.STATE.DEFAULT)
# create style style_screen8_roller_1_main_main_default
style_screen8_roller_1_main_main_default = lv.style_t()
style_screen8_roller_1_main_main_default.init()
style_screen8_roller_1_main_main_default.set_radius(5)
style_screen8_roller_1_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen8_roller_1_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen8_roller_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_roller_1_main_main_default.set_bg_opa(255)
style_screen8_roller_1_main_main_default.set_border_color(lv.color_make(0xe6,0xe6,0xe6))
style_screen8_roller_1_main_main_default.set_border_width(2)
style_screen8_roller_1_main_main_default.set_text_color(lv.color_make(0x33,0x33,0x33))

# add style for screen8_roller_1
screen8_roller_1.add_style(style_screen8_roller_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_roller_1_main_selected_default
style_screen8_roller_1_main_selected_default = lv.style_t()
style_screen8_roller_1_main_selected_default.init()
style_screen8_roller_1_main_selected_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_roller_1_main_selected_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_roller_1_main_selected_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_roller_1_main_selected_default.set_bg_opa(255)
style_screen8_roller_1_main_selected_default.set_text_color(lv.color_make(0xFF,0xFF,0xFF))

# add style for screen8_roller_1
screen8_roller_1.add_style(style_screen8_roller_1_main_selected_default, lv.PART.SELECTED|lv.STATE.DEFAULT)

screen8_roller_2 = lv.roller(screen8_tileview_1_tileview)
screen8_roller_2.set_pos(130,78)
screen8_roller_2.set_options("0\n1\n2\n3\n4\n5", lv.roller.MODE.INFINITE)
screen8_roller_2.set_visible_row_count(3)
try:
	screen8_roller_2.set_style_text_font(lv.font_arial_12, lv.PART.MAIN|lv.STATE.DEFAULT)
	screen8_roller_2.set_style_text_font(lv.font_arial_12, lv.PART.MAIN|lv.STATE.FOCUSED)
	screen8_roller_2.set_style_text_font(lv.font_arial_12, lv.PART.SELECTED|lv.STATE.DEFAULT)
except AttributeError:
	try:
		screen8_roller_2.set_style_text_font(lv.font_montserrat_12, lv.PART.MAIN|lv.STATE.DEFAULT)
		screen8_roller_2.set_style_text_font(lv.font_montserrat_12, lv.PART.MAIN|lv.STATE.FOCUSED)
		screen8_roller_2.set_style_text_font(lv.font_montserrat_12, lv.PART.SELECTED|lv.STATE.DEFAULT)
	except AttributeError:
		screen8_roller_2.set_style_text_font(lv.font_montserrat_16, lv.PART.MAIN|lv.STATE.DEFAULT)
		screen8_roller_2.set_style_text_font(lv.font_montserrat_16, lv.PART.MAIN|lv.STATE.FOCUSED)
		screen8_roller_2.set_style_text_font(lv.font_montserrat_16, lv.PART.SELECTED|lv.STATE.DEFAULT)
# create style style_screen8_roller_2_main_main_default
style_screen8_roller_2_main_main_default = lv.style_t()
style_screen8_roller_2_main_main_default.init()
style_screen8_roller_2_main_main_default.set_radius(5)
style_screen8_roller_2_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen8_roller_2_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen8_roller_2_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_roller_2_main_main_default.set_bg_opa(255)
style_screen8_roller_2_main_main_default.set_border_color(lv.color_make(0xe6,0xe6,0xe6))
style_screen8_roller_2_main_main_default.set_border_width(2)
style_screen8_roller_2_main_main_default.set_text_color(lv.color_make(0x33,0x33,0x33))

# add style for screen8_roller_2
screen8_roller_2.add_style(style_screen8_roller_2_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_roller_2_main_selected_default
style_screen8_roller_2_main_selected_default = lv.style_t()
style_screen8_roller_2_main_selected_default.init()
style_screen8_roller_2_main_selected_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_roller_2_main_selected_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_roller_2_main_selected_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_roller_2_main_selected_default.set_bg_opa(255)
style_screen8_roller_2_main_selected_default.set_text_color(lv.color_make(0xFF,0xFF,0xFF))

# add style for screen8_roller_2
screen8_roller_2.add_style(style_screen8_roller_2_main_selected_default, lv.PART.SELECTED|lv.STATE.DEFAULT)

screen8_roller_3 = lv.roller(screen8_tileview_1_tileview)
screen8_roller_3.set_pos(204,77)
screen8_roller_3.set_options("0\n1\n2\n3\n4\n5\n7\n8\n9", lv.roller.MODE.INFINITE)
screen8_roller_3.set_visible_row_count(3)
try:
	screen8_roller_3.set_style_text_font(lv.font_arial_12, lv.PART.MAIN|lv.STATE.DEFAULT)
	screen8_roller_3.set_style_text_font(lv.font_arial_12, lv.PART.MAIN|lv.STATE.FOCUSED)
	screen8_roller_3.set_style_text_font(lv.font_arial_12, lv.PART.SELECTED|lv.STATE.DEFAULT)
except AttributeError:
	try:
		screen8_roller_3.set_style_text_font(lv.font_montserrat_12, lv.PART.MAIN|lv.STATE.DEFAULT)
		screen8_roller_3.set_style_text_font(lv.font_montserrat_12, lv.PART.MAIN|lv.STATE.FOCUSED)
		screen8_roller_3.set_style_text_font(lv.font_montserrat_12, lv.PART.SELECTED|lv.STATE.DEFAULT)
	except AttributeError:
		screen8_roller_3.set_style_text_font(lv.font_montserrat_16, lv.PART.MAIN|lv.STATE.DEFAULT)
		screen8_roller_3.set_style_text_font(lv.font_montserrat_16, lv.PART.MAIN|lv.STATE.FOCUSED)
		screen8_roller_3.set_style_text_font(lv.font_montserrat_16, lv.PART.SELECTED|lv.STATE.DEFAULT)
# create style style_screen8_roller_3_main_main_default
style_screen8_roller_3_main_main_default = lv.style_t()
style_screen8_roller_3_main_main_default.init()
style_screen8_roller_3_main_main_default.set_radius(5)
style_screen8_roller_3_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen8_roller_3_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen8_roller_3_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_roller_3_main_main_default.set_bg_opa(255)
style_screen8_roller_3_main_main_default.set_border_color(lv.color_make(0xe6,0xe6,0xe6))
style_screen8_roller_3_main_main_default.set_border_width(2)
style_screen8_roller_3_main_main_default.set_text_color(lv.color_make(0x33,0x33,0x33))

# add style for screen8_roller_3
screen8_roller_3.add_style(style_screen8_roller_3_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_roller_3_main_selected_default
style_screen8_roller_3_main_selected_default = lv.style_t()
style_screen8_roller_3_main_selected_default.init()
style_screen8_roller_3_main_selected_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_roller_3_main_selected_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_roller_3_main_selected_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_roller_3_main_selected_default.set_bg_opa(255)
style_screen8_roller_3_main_selected_default.set_text_color(lv.color_make(0xFF,0xFF,0xFF))

# add style for screen8_roller_3
screen8_roller_3.add_style(style_screen8_roller_3_main_selected_default, lv.PART.SELECTED|lv.STATE.DEFAULT)

screen8_tileview_1_Title = screen8_tileview_1.add_tile(0 , 1, lv.DIR.TOP)
screen8_calendar_1 = lv.calendar(screen8_tileview_1_Title)
screen8_calendar_1.set_pos(0,40)
screen8_calendar_1.set_size(320,200)
screen8_calendar_1.set_today_date(time.localtime()[0], time.localtime()[1], time.localtime()[2])
screen8_calendar_1.set_showed_date(time.localtime()[0], time.localtime()[1])
highlighted_days=[
    lv.calendar_date_t({'year':2020, 'month':5, 'day':14})
]
screen8_calendar_1.set_highlighted_dates(highlighted_days, len(highlighted_days))
screen8_calendar_1_header = lv.calendar_header_arrow(screen8, screen8_calendar_1, 25)
def style_screen8_calendar_1_extra_ctrl_day_names_items_default_event_cb(e):
    obj = lv.btnmatrix.__cast__(e.get_target())
    dsc = lv.obj_draw_part_dsc_t.__cast__(e.get_param())
    if dsc.id < 7:
        dsc.label_dsc.color = lv.color_make(0x0D,0x30,0x55)
        try:
            lv.font_montserrat_12
            dsc.label_dsc.font = lv.font_montserrat_12
        except AttributeError:
            try:
                lv.font_montserrat_13
                dsc.label_dsc.font = lv.font_montserrat_13
            except AttributeError:
                dsc.label_dsc.font = lv.font_montserrat_16

screen8_calendar_1.add_event_cb(style_screen8_calendar_1_extra_ctrl_day_names_items_default_event_cb, lv.EVENT.DRAW_PART_BEGIN, None)

def style_screen8_calendar_1_extra_ctrl_highlight_items_default_event_cb(e):
    obj = lv.btnmatrix.__cast__(e.get_target())
    dsc = lv.obj_draw_part_dsc_t.__cast__(e.get_param())
    if obj.has_btn_ctrl(dsc.id, lv.btnmatrix.CTRL.CUSTOM_2):
        dsc.rect_dsc.bg_color = lv.color_make(0xff,0xff,0xff)
        dsc.rect_dsc.bg_grad_color = lv.color_make(0xff,0xff,0xff)
        dsc.rect_dsc.bg_grad_dir = lv.GRAD_DIR.VER
        dsc.rect_dsc.bg_opa = 255
        dsc.label_dsc.color = lv.color_make(0x0D,0x30,0x55)
        try:
            lv.font_montserrat_12
            dsc.label_dsc.font = lv.font_montserrat_12
        except AttributeError:
            try:
                lv.font_montserrat_13
                dsc.label_dsc.font = lv.font_montserrat_13
            except AttributeError:
                dsc.label_dsc.font = lv.font_montserrat_16

screen8_calendar_1.add_event_cb(style_screen8_calendar_1_extra_ctrl_highlight_items_default_event_cb, lv.EVENT.DRAW_PART_BEGIN, None)

def style_screen8_calendar_1_extra_ctrl_today_items_default_event_cb(e):
    obj = lv.btnmatrix.__cast__(e.get_target())
    dsc = lv.obj_draw_part_dsc_t.__cast__(e.get_param())
    if obj.has_btn_ctrl(dsc.id, lv.btnmatrix.CTRL.CUSTOM_1):
        dsc.rect_dsc.bg_color = lv.color_make(0x01,0xa2,0xb1)
        dsc.rect_dsc.bg_grad_color = lv.color_make(0x01,0xa2,0xb1)
        dsc.rect_dsc.bg_grad_dir = lv.GRAD_DIR.VER
        dsc.rect_dsc.bg_opa = 255
        dsc.rect_dsc.border_color = lv.color_make(0xc0,0xc0,0xc0)
        dsc.rect_dsc.border_width = 1
        dsc.label_dsc.color = lv.color_make(0x0D,0x30,0x55)
        try:
            lv.font_montserrat_12
            dsc.label_dsc.font = lv.font_montserrat_12
        except AttributeError:
            try:
                lv.font_montserrat_13
                dsc.label_dsc.font = lv.font_montserrat_13
            except AttributeError:
                dsc.label_dsc.font = lv.font_montserrat_16

screen8_calendar_1.add_event_cb(style_screen8_calendar_1_extra_ctrl_today_items_default_event_cb, lv.EVENT.DRAW_PART_BEGIN, None)

def style_screen8_calendar_1_extra_ctrl_other_month_items_default_event_cb(e):
    obj = lv.btnmatrix.__cast__(e.get_target())
    dsc = lv.obj_draw_part_dsc_t.__cast__(e.get_param())
    if dsc.id >= 7 and obj.has_btn_ctrl(dsc.id, lv.btnmatrix.CTRL.DISABLED):
        dsc.rect_dsc.bg_color = lv.color_make(0x01,0xa2,0xb1)
        dsc.rect_dsc.bg_grad_color = lv.color_make(0x01,0xa2,0xb1)
        dsc.rect_dsc.bg_grad_dir = lv.GRAD_DIR.VER
        dsc.rect_dsc.bg_opa = 0
        dsc.label_dsc.color = lv.color_make(0xA9,0xA2,0xA2)
        try:
            lv.font_montserrat_12
            dsc.label_dsc.font = lv.font_montserrat_12
        except AttributeError:
            try:
                lv.font_montserrat_13
                dsc.label_dsc.font = lv.font_montserrat_13
            except AttributeError:
                dsc.label_dsc.font = lv.font_montserrat_16

screen8_calendar_1.add_event_cb(style_screen8_calendar_1_extra_ctrl_other_month_items_default_event_cb, lv.EVENT.DRAW_PART_BEGIN, None)

# create style style_screen8_calendar_1_extra_header_main_default
style_screen8_calendar_1_extra_header_main_default = lv.style_t()
style_screen8_calendar_1_extra_header_main_default.init()
style_screen8_calendar_1_extra_header_main_default.set_bg_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_calendar_1_extra_header_main_default.set_bg_grad_color(lv.color_make(0x21,0x95,0xf6))
style_screen8_calendar_1_extra_header_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_calendar_1_extra_header_main_default.set_bg_opa(255)
style_screen8_calendar_1_extra_header_main_default.set_text_color(lv.color_make(0xff,0xff,0xff))
try:
    style_screen8_calendar_1_extra_header_main_default.set_text_font(lv.font_arial_12)
except AttributeError:
    try:
        style_screen8_calendar_1_extra_header_main_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen8_calendar_1_extra_header_main_default.set_text_font(lv.font_montserrat_16)

# add style for screen8_calendar_1_header
screen8_calendar_1_header.add_style(style_screen8_calendar_1_extra_header_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_calendar_1_main_main_default
style_screen8_calendar_1_main_main_default = lv.style_t()
style_screen8_calendar_1_main_main_default.init()
style_screen8_calendar_1_main_main_default.set_bg_color(lv.color_make(0xff,0xff,0xff))
style_screen8_calendar_1_main_main_default.set_bg_grad_color(lv.color_make(0xff,0xff,0xff))
style_screen8_calendar_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_calendar_1_main_main_default.set_bg_opa(255)
style_screen8_calendar_1_main_main_default.set_border_color(lv.color_make(0xc0,0xc0,0xc0))
style_screen8_calendar_1_main_main_default.set_border_width(1)

# add style for screen8_calendar_1
screen8_calendar_1.add_style(style_screen8_calendar_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_calendar_1_main_items_default
style_screen8_calendar_1_main_items_default = lv.style_t()
style_screen8_calendar_1_main_items_default.init()
style_screen8_calendar_1_main_items_default.set_bg_color(lv.color_make(0x01,0xa2,0xb1))
style_screen8_calendar_1_main_items_default.set_bg_grad_color(lv.color_make(0x01,0xa2,0xb1))
style_screen8_calendar_1_main_items_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_calendar_1_main_items_default.set_bg_opa(0)
style_screen8_calendar_1_main_items_default.set_border_color(lv.color_make(0xc0,0xc0,0xc0))
style_screen8_calendar_1_main_items_default.set_border_width(1)
style_screen8_calendar_1_main_items_default.set_text_color(lv.color_make(0x0D,0x30,0x55))
try:
    style_screen8_calendar_1_main_items_default.set_text_font(lv.font_arial_12)
except AttributeError:
    try:
        style_screen8_calendar_1_main_items_default.set_text_font(lv.font_montserrat_12)
    except AttributeError:
        style_screen8_calendar_1_main_items_default.set_text_font(lv.font_montserrat_16)

# add style for screen8_calendar_1
screen8_calendar_1.add_style(style_screen8_calendar_1_main_items_default, lv.PART.ITEMS|lv.STATE.DEFAULT)

# create style style_screen8_tileview_1_main_main_default
style_screen8_tileview_1_main_main_default = lv.style_t()
style_screen8_tileview_1_main_main_default.init()
style_screen8_tileview_1_main_main_default.set_radius(0)
style_screen8_tileview_1_main_main_default.set_bg_color(lv.color_make(0xf6,0xf6,0xf6))
style_screen8_tileview_1_main_main_default.set_bg_grad_color(lv.color_make(0xf6,0xf6,0xf6))
style_screen8_tileview_1_main_main_default.set_bg_grad_dir(lv.GRAD_DIR.VER)
style_screen8_tileview_1_main_main_default.set_bg_opa(255)

# add style for screen8_tileview_1
screen8_tileview_1.add_style(style_screen8_tileview_1_main_main_default, lv.PART.MAIN|lv.STATE.DEFAULT)

# create style style_screen8_tileview_1_main_scrollbar_default
style_screen8_tileview_1_main_scrollbar_default = lv.style_t()
style_screen8_tileview_1_main_scrollbar_default.init()
style_screen8_tileview_1_main_scrollbar_default.set_radius(0)
style_screen8_tileview_1_main_scrollbar_default.set_bg_color(lv.color_make(0xea,0xef,0xf3))
style_screen8_tileview_1_main_scrollbar_default.set_bg_opa(255)

# add style for screen8_tileview_1
screen8_tileview_1.add_style(style_screen8_tileview_1_main_scrollbar_default, lv.PART.SCROLLBAR|lv.STATE.DEFAULT)



def screen1_imgbtn_2_pressed_1_event_cb(e,screen6):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen6, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen1_imgbtn_2.add_event_cb(lambda e: screen1_imgbtn_2_pressed_1_event_cb(e,screen6), lv.EVENT.PRESSED, None)


def screen1_imgbtn_3_clicked_1_event_cb(e,screen8):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen8, lv.SCR_LOAD_ANIM.NONE, 1000, 1000, False)
screen1_imgbtn_3.add_event_cb(lambda e: screen1_imgbtn_3_clicked_1_event_cb(e,screen8), lv.EVENT.CLICKED, None)


def screen4_imgbtn_2_clicked_1_event_cb(e,screen2):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen2, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen4_imgbtn_2.add_event_cb(lambda e: screen4_imgbtn_2_clicked_1_event_cb(e,screen2), lv.EVENT.CLICKED, None)



def screen1_imgbtn_1_pressed_1_event_cb(e,screen2):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen2, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen1_imgbtn_1.add_event_cb(lambda e: screen1_imgbtn_1_pressed_1_event_cb(e,screen2), lv.EVENT.PRESSED, None)


def screen2_btn_1_pressed_1_event_cb(e,screen3):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen3, lv.SCR_LOAD_ANIM.NONE, 1000, 1000, False)
screen2_btn_1.add_event_cb(lambda e: screen2_btn_1_pressed_1_event_cb(e,screen3), lv.EVENT.PRESSED, None)


def screen2_btn_2_pressed_1_event_cb(e,screen4):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen4, lv.SCR_LOAD_ANIM.NONE, 1000, 1000, False)
screen2_btn_2.add_event_cb(lambda e: screen2_btn_2_pressed_1_event_cb(e,screen4), lv.EVENT.PRESSED, None)


def screen2_btn_3_clicked_1_event_cb(e,screen5):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen5, lv.SCR_LOAD_ANIM.NONE, 1000, 1000, False)
screen2_btn_3.add_event_cb(lambda e: screen2_btn_3_clicked_1_event_cb(e,screen5), lv.EVENT.CLICKED, None)


def screen2_btn_4_pressed_1_event_cb(e,screen7):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen7, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen2_btn_4.add_event_cb(lambda e: screen2_btn_4_pressed_1_event_cb(e,screen7), lv.EVENT.PRESSED, None)







def screen6_imgbtn_4_clicked_1_event_cb(e,screen1):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen1, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen6_imgbtn_4.add_event_cb(lambda e: screen6_imgbtn_4_clicked_1_event_cb(e,screen1), lv.EVENT.CLICKED, None)


def screen8_imgbtn_1_clicked_1_event_cb(e,screen1):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen1, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen8_imgbtn_1.add_event_cb(lambda e: screen8_imgbtn_1_clicked_1_event_cb(e,screen1), lv.EVENT.CLICKED, None)


def screen3_imgbtn_1_clicked_1_event_cb(e,screen2):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen2, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen3_imgbtn_1.add_event_cb(lambda e: screen3_imgbtn_1_clicked_1_event_cb(e,screen2), lv.EVENT.CLICKED, None)





def screen5_imgbtn_3_clicked_1_event_cb(e,screen2):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen2, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen5_imgbtn_3.add_event_cb(lambda e: screen5_imgbtn_3_clicked_1_event_cb(e,screen2), lv.EVENT.CLICKED, None)


def screen2_imgbtn_2_clicked_1_event_cb(e,screen1):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen1, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen2_imgbtn_2.add_event_cb(lambda e: screen2_imgbtn_2_clicked_1_event_cb(e,screen1), lv.EVENT.CLICKED, None)







def screen7_imgbtn_5_clicked_1_event_cb(e,screen2):
    src = e.get_target()
    code = e.get_code()
    lv.scr_load_anim(screen2, lv.SCR_LOAD_ANIM.NONE, 500, 500, False)
screen7_imgbtn_5.add_event_cb(lambda e: screen7_imgbtn_5_clicked_1_event_cb(e,screen2), lv.EVENT.CLICKED, None)




# content from custom.py

# Load the default screen
lv.scr_load(screen1)

while SDL.check():
    time.sleep_ms(5)
